#! /usr/bin/env python3
# #################################################################################### #
#                                                                                      #
# actionc: Task "Action" and Profile "condition" dictionary                            #
#                                                                                      #
#  Provide the master lookup for a given <code>nnn</code> xml statement                #
#  level 1 key = the code (nnn, above)                                                 #
#   numargs subkey = the maximum number of argn xml lines in the action                #
#      if it = 99, then this is a referral to another entry, which is identified       #
#      in 'args'                                                                       #
#   args subkey = the specific arg number  keys with a 's' or 'e' are Profile          #
#    conditions                                                                        #
#        ...'e'=event, 's'=state, 't'=task                                             #
#   display subkey = the name to output - required                                     #
#   reqargs subkey = the requirement arg statement numbers for evaluation - optional   #
#   evalargs subkey = formula for evaluation - optional                                #
#      'some_string:' for str or int xml values                                        #
#      ['', 'e', 'some_string'] for boolean: 1 = display string, 0 = no display - optl #
#                                                                                      #
#      ['some_string:', 'l', 'lookup-code] for actiont dictionary lookup for specific  #
#       code.                                                                          #
#                                                                                      #
# GNU General Public License v3.0                                                      #
# Permissions of this strong copyleft license are conditioned on making available      #
# complete source code of licensed works and modifications, which include larger works #
# using a licensed work, under the same license. Copyright and license notices must be #
# preserved. Contributors provide an express grant of patent rights.                   #
# #################################################################################### #
from collections import namedtuple

# from typing import List

ActionCode = namedtuple(
    "ActionCode",
    ["numargs", "redirect", "args", "types", "display", "reqargs", "evalargs"],
)

action_codes = {
    "1000e": ActionCode(
        0, "", ["0"], ["Int"], "Display Unlocked", ["0"], [["Priority:", "l", "4s"]]
    ),
    "1000s": ActionCode(0, "", [], [], "Plugin", [], []),
    "1000t": ActionCode(0, "", [], [], "Plugin", [], []),
    "100s": ActionCode(0, "", [], [], "Airplane Mode", [], []),
    "100t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Str", "Int", "ConditionList"],
        "Search",
        ["0", "1"],
        ["Number:", ["", "e", "Info"]],
    ),
    "101t": ActionCode(0, "", [], [], "Take Photo", [], []),
    "102t": ActionCode(0, "", [], [], "Open File", [], []),
    "103s": ActionCode(0, "", [], [], "Light Level", ["0"], []),
    "104s": ActionCode(0, "", [], [], "Pressure", [], []),
    "104t": ActionCode(0, "", [], [], "Browse URL", [], []),
    "1040876951t": ActionCode(
        5,
        "",
        ["0", "1", "2", "3", "4"],
        ["Bundle", "Str", "Str", "Int", "Int"],
        "AutoInput UI Query",
        ["0", "3", "4"],
        ["", "Timeout:", ["", "e", ", Structure Output (JSON, etc)"]],
    ),
    "105s": ActionCode(0, "", [], [], "Media Button", [], []),
    "105t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Str", "Int", "Str"],
        "Set Clipboard",
        ["0", "1", "2"],
        ["Text:", ["", "e", ", Add"], "Image:"],
    ),
    "106s": ActionCode(0, "", [], [], "Magnetic Field", [], []),
    "107s": ActionCode(0, "", [], [], "Missed Call", [], []),
    "107361459t": ActionCode(0, "1040876951t", [], [], "AutoInput Actions V2", [], []),
    "109t": ActionCode(0, "", [], [], "Set Wallpaper", [], []),
    "1099157652t": ActionCode(0, "1040876951t", [], [], "AutoTools Json Write", [], []),
    "10s": ActionCode(1, "", ["0"], ["Int"], "Power", ["0"], [["Set:", "l", "10s"]]),
    "110s": ActionCode(
        6,
        "",
        ["0", "1", "2", "3", "4", "5"],
        ["Int", "Int", "Int", "Int", "Int", "Int"],
        "Mobile Network",
        ["0", "1", "2", "3", "4", "5"],
        [
            ["", "e", "2G"],
            ["", "e", "3G"],
            ["", "e", "3G-HSPA"],
            ["", "e", "4G"],
            ["", "e", "5G"],
            [", Active:", "l", "160"],
        ],
    ),
    "111t": ActionCode(0, "", [], [], "Compose MMS", [], []),
    "112t": ActionCode(0, "", [], [], "Run SL4A Script", [], []),
    "1120274117t": ActionCode(0, "1040876951t", [], [], "Locus Map", [], []),
    "1132319851t": ActionCode(0, "1040876951t", [], [], "AutoSheets Add Sheet", [], []),
    "1133159835e": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Bundle", "Str", "Str", "Int"],
        "AutoShare Process Text",
        ["0", "3"],
        ["", ["", "e", ", Structure Output (JSON, etc)"]],
    ),
    "1138194991s": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Bundle", "Str", "Str", "Int"],
        "AutoWear State",
        ["0", "3"],
        ["", ["", "e", "Structure Output (JSON (etc)"]],
    ),
    "1138588429t": ActionCode(0, "1040876951t", [], [], "Join Send Query", [], []),
    "113t": ActionCode(0, "", [], [], "WiFi Tether", [], []),
    "114t": ActionCode(0, "", [], [], "USB Tether", [], []),
    "1150542767e": ActionCode(0, "1040876951t", [], [], "Tap Tap Plugin", [], []),
    "116t": ActionCode(0, "", [], [], "HTTP Post", [], []),
    "1164968315t": ActionCode(
        0, "1040876951t", [], [], "AutoSpotify Play Media", [], []
    ),
    "1165325195t": ActionCode(0, "1040876951t", [], [], "AutoTools Web Screen", [], []),
    "117t": ActionCode(0, "", [], [], "HTTP Head", [], []),
    "117240295t": ActionCode(0, "1040876951t", [], [], "AutoWear Input", [], []),
    "118t": ActionCode(0, "", [], [], "HTTP Get", [], []),
    "1186637727t": ActionCode(
        0, "1040876951t", [], [], "KWGT Kustom Widget Maker", [], []
    ),
    "119t": ActionCode(
        5,
        "",
        ["0", "1", "2", "3", "4"],
        ["Int", "Str", "Str", "Int", "Str"],
        "Open Map",
        ["0", "1", "2", "3", "4"],
        [["Mode:", "l", "119"], ", Address:", ", Lat, Long:", ", Zoom:", ", Label:"],
    ),
    "120s": ActionCode(
        1, "", ["0"], ["Int"], "Orientation", ["0"], [["Is:", "l", "120s"]]
    ),
    "122375409t": ActionCode(0, "1040876951t", [], [], "AutoWeb Web Services", [], []),
    "122s": ActionCode(
        1, "", ["0"], ["Int"], "Display Orientation", ["0"], [["Is:", "l", "122s"]]
    ),
    "123s": ActionCode(
        8,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7"],
        ["Str", "Int", "Int", "Str", "Str", "Str", "Int", "Int"],
        "Display State",
        ["0"],
        [["", "e", "switch_set"]],
    ),
    "123t": ActionCode(
        8,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7"],
        ["Str", "Int", "Int", "Str", "Str", "Str", "Int", "Int"],
        "Run Shell",
        ["0", "1", "2", "3", "4", "5"],
        [
            "Command:",
            ", Timeout:",
            ["", "e", ", Use Root"],
            ", Store Output In:",
            ", Store Errors In:",
            ", Timeout:",
            ["", "e", ", Use Task Set0tings"],
        ],
    ),
    "1246578872t": ActionCode(
        0, "1040876951t", [], [], "AutoWear Notification", [], []
    ),
    "124t": ActionCode(0, "", [], [], "Remount", [], []),
    "1250249549t": ActionCode(
        0, "1040876951t", [], [], "AutoInput Screen Off/On", [], []
    ),
    "125s": ActionCode(
        3, "", ["0", "1", "2"], ["Str", "Str", "Str"], "Proximity Sensor", [], []
    ),
    "125t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Str", "Str", "Str"],
        "Compose Email",
        ["0", "1", "2"],
        ["Recipient(s):", ", Subject:", ", Message:"],
    ),
    "126t": ActionCode(
        6,
        "",
        ["0", "1", "2", "3", "4", "5"],
        ["Str", "Int", "Int", "Int", "Str", "ConditionList"],
        "Return",
        ["0", "1", "2", "3", "4"],
        [
            "Value:",
            ["", "e", ", Stop"],
            ["", "e", ", Local Variable Passthrough"],
            ["", "e", ", Replace On Passthrough"],
            ", Limit Passthrough To:",
        ],
    ),
    "129t": ActionCode(
        5,
        "",
        ["0", "1", "2", "3", "4"],
        ["Str", "Str", "Int", "Int", "ConditionList"],
        "JavaScriptLet",
        ["0", "1", "2", "3"],
        ["Code:", ", Libraries:", ["", "e", ", Auto Exit"], ", Timeout:"],
    ),
    "12s": ActionCode(0, "", [], [], "HDMI Plugged", [], []),
    "1304982781t": ActionCode(0, "1040876951t", [], [], "AutoTools Dialog", [], []),
    "130t": ActionCode(
        12,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11"],
        [
            "Str",
            "Int",
            "Str",
            "Str",
            "Str",
            "Int",
            "Int",
            "Str",
            "Int",
            "Int",
            "Int",
            "ConditionList",
        ],
        "Perform Task",
        ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10"],
        [
            "Name:",
            ", Priority:",
            ", Parameter 1:",
            ", Parameter 2:",
            ", Return Value Variable:",
            ["", "e", ", Stop"],
            ["", "e", ", Local Variable Passthrough"],
            ", Limit Passthrough To:",
            ["", "e", ", Reset Return Variable"],
            ["", "e", ", Allow Overwrite Variables"],
            ["", "e", ", Structure Output (JSON, etc)"],
        ],
    ),
    "131t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Str", "Str", "Int", "Int"],
        "JavaScript",
        ["0", "1", "2"],
        ["Path:", ", Libraries:", ["", "e", ", Auto Exit"], ", Timeout:"],
    ),
    "1339942270t": ActionCode(0, "1040876951t", [], [], "SharpTools Thing", [], []),
    "133t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Int", "Int", "Int"],
        "Set Tasker Pref",
        ["0", "1"],
        [["Set:", "l", "133"], ", Value:"],
    ),
    "1339291165t": ActionCode(0, "1040876951t", [], [], "AutoWeb Download", [], []),
    "1344888481e": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Bundle", "Str", "Str", "Int"],
        "Notification Listener",
        ["0", "3"],
        ["", ["", "e", ", Structure Output (JSON, etc)"]],
    ),
    "134e": ActionCode(0, "", [], [], "Card Mounted", [], []),
    "134t": ActionCode(1, "", ["0"], ["Str"], "Query Action", ["0"], ["Action:"]),
    "135e": ActionCode(0, "", [], [], "Card Unmounted", [], []),
    "135s": ActionCode(0, "", [], [], "Auto-Sync", [], []),
    "135t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Int", "Int", "Str", "ConditionList"],
        "Go To",
        ["0", "1", "2"],
        [["Set:", "l", "135"], ", Number:", ", Label:"],
    ),
    "136e": ActionCode(0, "", [], [], "Card Removed", [], []),
    "136s": ActionCode(0, "", [], [], "VPN Connected", [], []),
    "136t": ActionCode(
        1, "", ["0"], ["Int"], "Sound Effects", ["0"], [["Set:", "l", "switch_set"]]
    ),
    "137t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Int", "Str", "ConditionList"],
        "Stop",
        ["0", "1"],
        [["", "e", "Stop"], ", Task:"],
    ),
    "138t": ActionCode(1, "", ["0"], ["Img"], "Set Tasker Icon", ["0"], ["Icon:"]),
    "139t": ActionCode(0, "", [], [], "Disable (Tasker)", [], []),
    "140618776t": ActionCode(0, "1040876951t", [], [], "AutoWear Toast", [], []),
    "140s": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Int", "Int"],
        "Battery Level",
        ["0", "1"],
        ["From:", ", To:"],
    ),
    "140t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Str", "Str"],
        "Change Icon Set",
        ["0", "1"],
        ["Old:", ", New:"],
    ),
    "1410790256t": ActionCode(
        0, "1040876951t", [], [], "AutoWear Floating Icon", [], []
    ),
    "141s": ActionCode(0, "", [], [], "Battery Temperature", [], []),
    "1411074191t": ActionCode(0, "1040876951t", [], [], "AutoSheets Add Rows", [], []),
    "142s": ActionCode(
        2, "", ["0", "1"], ["Str", "Str"], "Profile Active", ["0"], ["Name:"]
    ),
    "142t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Str", "Str"],
        "Edit Task",
        ["0", "1"],
        ["Task:", ", Action:"],
    ),
    "143s": ActionCode(
        2, "", ["0", "1"], ["Str", "Str"], "Task Running", ["0"], ["Name:"]
    ),
    "143t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Str", "Str"],
        "Edit Scene",
        ["0", "1"],
        ["Scene Name:", ", Element:"],
    ),
    "144741820t": ActionCode(
        0, "1040876951t", [], [], "AutoNotification Hide Notification Icons", [], []
    ),
    "1446679033t": ActionCode(0, "1040876951t", [], [], "AutoTools Time", [], []),
    "1446874931t": ActionCode(0, "1040876951t", [], [], "AutoTools Json Read", [], []),
    "1447159672t": ActionCode(0, "1040876951t", [], [], "AutoTools Text", [], []),
    "1447244736t": ActionCode(
        0, "1040876951t", [], [], "AutoTools Action Wait", [], []
    ),
    "1446697909t": ActionCode(0, "1040876951t", [], [], "AutoWear Dialog", [], []),
    "145s": ActionCode(0, "", [], [], "Signal Strength", [], []),
    "1452528931t": ActionCode(
        0, "1040876951t", [], [], "AutoContacts Query 2.0", [], []
    ),
    "1461810131t": ActionCode(
        0, "1040876951t", [], [], "AutoSheets Update Cells", [], []
    ),
    "147s": ActionCode(0, "", [], [], "Unread Text", [], []),
    "147t": ActionCode(
        1, "", ["0"], ["Int"], "Show Prefs", ["0"], [["Section:", "l", "147"]]
    ),
    "148s": ActionCode(0, "", [], [], "Pen Out", [], []),
    "148t": ActionCode(0, "", [], [], "Show Runlog", [], []),
    "1482108003t": ActionCode(
        0, "1040876951t", [], [], "AutoSpotify Player State", [], []
    ),
    "149s": ActionCode(0, "", [], [], "Pen Menu", [], []),
    "14s": ActionCode(0, "", [], [], "Power Save Mode", [], []),
    "1508929357t": ActionCode(0, "1040876951t", [], [], "AutoTools Array", [], []),
    "150s": ActionCode(
        1, "", ["0"], ["Int"], "USB Connected", ["0"], [["Is:", "l", "150s"]]
    ),
    "150t": ActionCode(0, "", [], [], "Keyguard", [], []),
    "1520257414e": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Bundle", "Str", "Str", "Int"],
        "AutoNotification Intercept",
        ["0", "3"],
        ["", ["", "e", ", Structure Output (JSON, etc)"]],
    ),
    "152t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Str", "Img"],
        "Set Widget Icon",
        ["0", "1"],
        ["Name:", ", Icon:"],
    ),
    "153t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Int", "Int", "Str"],
        "Import Data",
        ["0", "1", "2"],
        [["Type:", "l", "153"], ["Source:", "l", "153a"], ", Variable:"],
    ),
    "154s": ActionCode(0, "", [], [], "Active User", [], []),
    "155t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Str", "Str"],
        "Set Widget Label",
        ["0", "1"],
        ["Name:", ", Label:"],
    ),
    "1563355455t": ActionCode(
        0, "1040876951t", [], [], "AutoNotification Buttons Notification", [], []
    ),
    "1563799945t": ActionCode(0, "1040876951t", [], [], "Secure Settings", [], []),
    "156t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Int", "Int", "Int", "Str"],
        "MIDI Play",
        ["0", "1", "2", "3"],
        [
            ["Format:", "l", "156"],
            ["Locality:", "l", "156a"],
            ", Best Timing:",
            ", Score:",
        ],
    ),
    "157t": ActionCode(0, "", [], [], "Quick Setting Add", [], []),
    "158t": ActionCode(0, "", [], [], "Quick Setting Remove", [], []),
    "159t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Str", "Int", "ConditionList"],
        "Profile Status",
        ["0", "1"],
        ["Name:", ["Set:", "l", "switch_set"]],
    ),
    "15t": ActionCode(
        7,
        "",
        ["0", "1", "2", "3", "4", "5", "6"],
        ["Str", "Str", "Int", "Int", "Int", "Str", "Str"],
        "Lock",
        ["2", "3", "4", "5", "6"],
        [
            ["", "e", "Allow Cancel"],
            ["", "e", "Remember Till Off"],
            ["", "e", "Full Screen"],
            ", Background Image:",
            ", Layout:",
        ],
    ),
    "160s": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Str", "Str", "Str", "Int"],
        "Wifi Connected",
        ["0", "1", "2", "3"],
        ["SSID:", ", MAC:", ", IP", ["Active:", "l", "160"]],
    ),
    "1600958131t": ActionCode(
        0, "1040876951t", [], [], "AutoBubbles Create Bubble", [], []
    ),
    "161s": ActionCode(0, "", [], [], "Ethernet Connect", [], []),
    "161t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Str", "Str", "Str", "Str"],
        "Setup App Shortcuts",
        ["0", "1", "2", "3"],
        ["Task:", ", Task:", ", Task:", ", Task:"],
    ),
    "1620773086t": ActionCode(0, "1040876951t", [], [], "SharpTools A Thing", [], []),
    "162t": ActionCode(
        13,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12"],
        [
            "Int",
            "Str",
            "Int",
            "Int",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
        ],
        "Setup Quick Setting Tile",
        ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12"],
        [
            ["Number:", "l", "162"],
            ", Task:",
            [", Status:", "l", "162a"],
            ["", "e", ", Can Use On Locked Device"],
            ", Long Click Task:",
            ", Double Click Task:",
            ", Subtitle:",
            ", Icon:",
            ", Label:",
            ", Command:",
            ", Long Click Command:",
            ", Double Click Command:",
            ", Command Prefix:",
        ],
    ),
    "1643249237t": ActionCode(0, "1040876951t", [], [], "Tools & AmazFit", [], []),
    "1644316156t": ActionCode(
        0, "1040876951t", [], [], "AutoNotification Reply", [], []
    ),
    "1646792910t": ActionCode(
        0, "1040876951t", [], [], "AutoTools Secure Settings", [], []
    ),
    "165s": ActionCode(1, "", ["0"], ["ConditionList"], "Variable Value", [], []),
    "165t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Int", "Int", "Int", "Str"],
        "Cancel Alarm",
        ["0", "1"],
        [["Mode:", "l", "165"], ", Minutes:"],
    ),
    "166160670t": ActionCode(
        0, "1040876951t", [], [], "AutoVoice Natural Language", [], []
    ),
    "1664218170e": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Bundle", "Str", "Str", "Int"],
        "AutoVoice Natural Language",
        ["3"],
        [["", "e", ", Structure Output (JSON, etc)"]],
    ),
    "1668911626e": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Bundle", "Str", "Str", "Int"],
        "Join",
        ["0", "3"],
        ["", ["", "e", ", Structure Output (JSON, etc)"]],
    ),
    "166t": ActionCode(0, "", [], [], "Show Alarms", [], []),
    "1677547919t": ActionCode(
        0, "1040876951t", [], [], "AutoNotification Actions", [], []
    ),
    "1687767515t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Bundle", "Str", "Str", "Int"],
        "AutoInput Modes",
        ["0", "3"],
        ["", ["", "e", ", Structure Output (JSON, etc)"]],
    ),
    "1691829355e": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Bundle", "Str", "Str", "Int"],
        "SharpTools Thing",
        ["0"],
        [""],
    ),
    "16s": ActionCode(0, "", [], [], "Device Idle", [], []),
    "16t": ActionCode(0, "", [], [], "System Lock", [], []),
    "170s": ActionCode(0, "", [], [], "Wifi Near", [], []),
    "171109731t": ActionCode(
        0, "1040876951t", [], [], "AutoWeb Authentication", [], []
    ),
    "171t": ActionCode(
        5,
        "",
        ["0", "1", "2", "3", "4"],
        ["Int", "Int", "Int", "Int", "ConditionList"],
        "Beep",
        ["0", "1", "2", "3"],
        ["Frequency:", ", Duration:", ", Amplitude", ["Stream:", "l", "171"]],
    ),
    "172t": ActionCode(
        5,
        "",
        ["0", "1", "2", "3", "4"],
        ["Str", "Int", "Int", "Int", "Int"],
        "Morse",
        ["0", "1", "2", "3", "4"],
        [
            "Text:",
            ", Frequency:",
            ", Speed:",
            ", Amplitude:",
            [", Stream:", "l", "171"],
        ],
    ),
    "1732635924t": ActionCode(0, "1040876951t", [], [], "AutoInput Action", [], []),
    "173t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Int", "App"],
        "Network Access",
        ["0"],
        [["Mode:", "l", "173"]],
    ),
    "175s": ActionCode(0, "", [], [], "Dreaming", [], []),
    "175t": ActionCode(
        1, "", ["0"], ["Int"], "Power Mode", ["0"], [["Mode:", "l", "175"]]
    ),
    "1754437993t": ActionCode(
        0, "1040876951t", [], [], "AutoVoice Recognition", [], []
    ),
    "176t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Str", "Int"],
        "Take Screenshot",
        ["0", "1"],
        ["File:", ["", "e", ", Insert In Gallery"]],
    ),
    "177t": ActionCode(
        1, "", ["0"], ["Int"], "Haptic Feedback", ["0"], [["Set:", "l", "switch_set"]]
    ),
    "1788518030e": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Bundle", "Str", "Str", "Int"],
        "AutoInput Key",
        ["0", "3"],
        ["", ["", "e", ", Structure Output (JSON, etc)"]],
    ),
    "1795842217t": ActionCode(0, "1040876951t", [], [], "AutoLaunch", [], []),
    "180s": ActionCode(0, "", [], [], "Temperature", [], []),
    "1804737413t": ActionCode(
        0, "1040876951t", [], [], "AutoWear Secure Settings", [], []
    ),
    "1810865467t": ActionCode(0, "1040876951t", [], [], "AutoSheets Get Data", [], []),
    "1810891651t": ActionCode(0, "1040876951t", [], [], "AutoSheets Get Cell", [], []),
    "1825107102e": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Bundle", "Str", "Str", "Int"],
        "AutoNotification",
        ["0", "3"],
        ["", ["", "e", ", Structure Output (JSON, etc)"]],
    ),
    "182s": ActionCode(0, "", [], [], "Heart Rate", [], []),
    "1830656901t": ActionCode(
        0, "1040876951t", [], [], "AutoWear List Screens", [], []
    ),
    "1830829821t": ActionCode(0, "1040876951t", [], [], "AutoWear 4 Screen", [], []),
    "185s": ActionCode(0, "", [], [], "Humidity", [], []),
    "185t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Int", "Int"],
        "Filter Image",
        ["0", "1"],
        [["Mode:", "l", "185"], ", Threshold:"],
    ),
    "1861978578e": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Bundle", "Str", "Str", "Int"],
        "AutoWear Command/Command Filter",
        ["0", "3"],
        ["", ["", "e", ", Structure Output (JSON, etc)"]],
    ),
    "186s": ActionCode(
        6,
        "",
        ["0", "1", "2", "3", "4", "5"],
        ["Int", "Str", "Str", "Int", "Str", "ConditionList"],
        "Custom Setting",
        ["0", "1", "2", "3", "4"],
        [
            ["Test:", "l", "235"],
            ", Name:",
            ", Value:",
            ["", "e", "Use Root"],
            ", Read Setting To:",
        ],
    ),
    "187t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Str", "Int", "Int"],
        "Save Image",
        ["0", "1", "2"],
        ["File:", ", Image Quality:", ["", "e", ", Delete From Memory After"]],
    ),
    "188s": ActionCode(
        3, "", ["0", "1", "2"], ["Img", "Int", "Int"], "Dark Mode", [], []
    ),
    "188t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Img", "Int", "Int"],
        "Load Image",
        ["0", "1", "2"],
        ["Source:", ", Max Width or Height:", ["", "e", ", Respect EXIF Orientation"]],
    ),
    "18927444e": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Bundle", "Str", "Str", "Int"],
        "AutoApps Command",
        ["3"],
        [["", "e", ", Structure Output (JSON, etc)"]],
    ),
    "189t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Int", "Int", "Int", "Int"],
        "Crop Image",
        ["0", "1", "2", "3"],
        [
            "From Left (%):",
            ", From Right (%):",
            ", From Top (%):",
            ", From Bottom (%):",
        ],
    ),
    "18t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["App", "Int"],
        "Kill App",
        ["0", "1"],
        [["a", "", "App:"], ["", "e", "Use Root"]],
    ),
    "190s": ActionCode(0, "", [], [], "Any Sensor", [], []),
    "190t": ActionCode(
        1, "", ["0"], ["Int"], "Flip Image", ["0"], [["Direction:", "l", "190"]]
    ),
    "1910383148t": ActionCode(0, "1040876951t", [], [], "AutoTools Regex", [], []),
    "1912522764t": ActionCode(0, "1040876951t", [], [], "AutoTools Toast", [], []),
    "191971507t": ActionCode(
        5,
        "",
        ["0", "1", "2", "3", "4"],
        ["Bundle", "Str", "Str", "Int", "Int"],
        "AutoWear ADB Wifi",
        ["3"],
        [["", "e", ", Structure Output (JSON, etc)"]],
    ),
    "191t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Int", "Int"],
        "Rotate Image",
        ["0", "1"],
        [["Direction:", "l", "191"], [", Degrees:", "l", "191a"]],
    ),
    "192s": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Bundle", "Str"],
        "Matter Light",
        ["1"],
        ["Device IDs/Names:"],
    ),
    "192t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Int", "Str", "Int"],
        "Play Ringtone",
        ["0", "1", "2"],
        [["Direction:", "l", "192"], ", Sound:", [", Stream:", "l", "171"]],
    ),
    "193t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Int", "Int"],
        "Resize Image",
        ["0", "1"],
        ["Width:", ", Height:"],
    ),
    "194s": ActionCode(0, "", [], [], "Work Profile", [], []),
    "194t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Str", "Int", "Str"],
        "Test Scene",
        ["0", "1", "2"],
        ["Name:", [", Test:", "l", "194"], ", Store Result In:"],
    ),
    "1957670352t": ActionCode(0, "1040876951t", [], [], "AutoWear App", [], []),
    "1957681000e": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Bundle", "Str", "Str", "Int"],
        "AutoInput Gesture",
        ["0", "3"],
        ["", ["", "e", ", Structure Output (JSON, etc)"]],
    ),
    "195s": ActionCode(0, "", [], [], "NFC Status", [], []),
    "195t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Str", "Str", "Int", "Str"],
        "Test Element",
        ["0", "1", "2", "3"],
        ["Scene Name:", ", Element:", [", Test:", "l", "195"], ", Store Result In:"],
    ),
    "197t": ActionCode(0, "", [], [], "Developer Settings", [], []),
    "198t": ActionCode(0, "", [], [], "Device Info Settings", [], []),
    "199t": ActionCode(0, "", [], [], "Add Account Settings", [], []),
    "199558826t": ActionCode(0, "1040876951t", [], [], "TouchTask Gestures", [], []),
    "2000e": ActionCode(
        2,
        "",
        ["0", "1"],
        ["App", "Str"],
        "Notification Click",
        ["0", "1"],
        ["Owner Application:", ", Title:"],
    ),
    "2003e": ActionCode(0, "", [], [], "Missed Call", [], []),
    "2005e": ActionCode(0, "", [], [], "SMS Success", [], []),
    "200t": ActionCode(0, "", [], [], "All Settings", [], []),
    "2010e": ActionCode(0, "", [], [], "SMS Failure", [], []),
    "201e": ActionCode(
        4,
        "",
        ["0", "1", "2", "3", "4"],
        ["App", "Str", "Str", "Str"],
        "Assistance Request",
        ["0", "1", "2", "3"],
        ["App:", ", URL:", ", Texts:", ", Extras:", [", Priority:", "4s"]],
    ),
    "201t": ActionCode(0, "", [], [], "Airplane Mode Settings", [], []),
    "2010186613t": ActionCode(
        0, "1040876951t", [], [], "AutoSheets Delete Cell Content", [], []
    ),
    "202t": ActionCode(0, "", [], [], "APN Settings", [], []),
    "2022280279t": ActionCode(
        0, "1040876951t", [], [], "AutoNotification Media", [], []
    ),
    "203e": ActionCode(
        0, "", [], [], "Battery Changed", ["0"], [["Priority:", "l", "4s"]]
    ),
    "203t": ActionCode(0, "", [], [], "Date Settings", [], []),
    "2046367074t": ActionCode(
        0, "1040876951t", [], [], "AutoNotification Cancel", [], []
    ),
    "2041559229t": ActionCode(
        0, "1040876951t", [], [], "AutoSpotify Playlists", [], []
    ),
    "204t": ActionCode(0, "", [], [], "Internal Storage Settings", [], []),
    "2050e": ActionCode(0, "", [], [], "Quick Setting Clicked", [], []),
    "205e": ActionCode(0, "", [], [], "Battery Full", [], []),
    "2051074546t": ActionCode(
        0, "1040876951t", [], [], "AutoSpotify Control Media", [], []
    ),
    "206e": ActionCode(0, "", [], [], "Battery Overheating", [], []),
    "206t": ActionCode(0, "", [], [], "Wireless Settings", [], []),
    "2075e": ActionCode(
        2,
        "",
        ["0", "1", "2"],
        ["Int", "Str", "Str"],
        "Custom Setting",
        ["0", "1", "2"],
        [["Type:", "l", "235"], ", Name:", ", Value:"],
    ),
    "2076e": ActionCode(
        2, "", ["0", "1"], ["Str", "Str"], "NFC Tag", ["0", "1"], ["ID:", ", Content:"]
    ),
    "2077e": ActionCode(1, "", ["0"], ["Bundle"], "Secondary App Opened", [], []),
    "2078e": ActionCode(
        2, "", ["0", "1"], ["Bundle", "Str"], "App Changed", ["1"], ["Package:"]
    ),
    "2079e": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Int", "Str"],
        "Volume Long Press",
        ["0", "1"],
        [["Type:", "l", "2079e"], ", Additional Time:"],
    ),
    "2080e": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Bundle", "Str", "Str", "ConditionList"],
        "BT Connected",
        ["1", "2"],
        ["Name:", ", Address:"],
    ),
    "2081e": ActionCode(
        6,
        "",
        ["0", "1", "2", "3", "4", "5"],
        ["Bundle", "Str", "Str", "Str", "Str", "Int"],
        "Music Track Changed",
        ["1", "2", "3", "4", "5"],
        ["Track:", ", Album:", ", Artist", ", Package:", [", Type:", "l", "2081e"]],
    ),
    "2083e": ActionCode(0, "", [], [], "Significant Motion", [], []),
    "2084e": ActionCode(0, "", [], [], "Alarm Changed", [], []),
    "2085e": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Bundle", "Str", "Str", "Int"],
        "Logcat Entry",
        ["1", "2", "3"],
        ["Component:", ", Filter:", ["", "e", ", Grep Filter"]],
    ),
    "2088e": ActionCode(0, "", [], [], "Any Sensor", [], []),
    "2089e": ActionCode(
        8,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7"],
        ["Bundle", "Int", "Str", "Str", "Str", "Int", "Int", "Str"],
        "HTTP Request",
        ["1", "2", "3", "4", "5", "6", "7"],
        [
            "Port:",
            ", Method:",
            ", Path:",
            ", Quick Response",
            ", Timeout:",
            ["", "e", ", Only On Wifi"],
            ", Network Name/MAC Address:",
        ],
    ),
    "208e": ActionCode(0, "", 0, [], "Display On", ["0"], [["Priority:", "l", "4s"]]),
    "208t": ActionCode(0, "", [], [], "Location Settings", [], []),
    "2091e": ActionCode(
        6,
        "",
        ["0", "1", "2", "3"],
        ["Bundle", "Str", "Str", "Int"],
        "Logcat Entry",
        ["1", "2", "3"],
        ["Component:", ", Filter:", ["", "e", ", Grep Filter"]],
    ),
    "2092e": ActionCode(0, "", [], [], "Power Menu Shown", [], []),
    "2093e": ActionCode(
        1, "", ["0"], ["App", "Str"], "Assistant Action", ["0"], ["Command:"]
    ),
    "2094e": ActionCode(0, "", [], [], "Call Screened", [], []),
    "2095e": ActionCode(
        2, "", ["0", "1"], ["Bundle", "Str"], "Tick", ["1"], ["Interval (ms):"]
    ),
    "2096e": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Bundle", "Int", "Int", "Int"],
        "Sleeping",
        ["1", "2", "3"],
        ["Minimum Confidence:", ", Maximum Light:", ", Maximum Motion:"],
    ),
    "20t": ActionCode(
        5,
        "",
        ["0", "1", "2", "3", "4"],
        ["App", "Str", "Int", "Int", "ConditionList"],
        "Launch App",
        ["0", "1", "2", "3"],
        [
            ["a", "", "App:"],
            ", Data:",
            ["", "e", "Exclude From Recent Apps"],
            ["", "e", "Always Start New Copy"],
            ["if"],
        ],
    ),
    "210e": ActionCode(0, "", 0, [], "Display Off", ["0"], [["Priority:", "l", "4s"]]),
    "210t": ActionCode(0, "", [], [], "Input Method Settings", [], []),
    "211t": ActionCode(0, "", [], [], "Sync Settings", [], []),
    "211707263t": ActionCode(0, "1040876951t", [], [], "Global Actions", [], []),
    "211905330t": ActionCode(0, "1040876951t", [], [], "AutoContacts", [], []),
    "2114100406t": ActionCode(0, "1040876951t", [], [], "AutoLaunch Query", [], []),
    "212t": ActionCode(0, "", [], [], "WiFi IP Settings", [], []),
    "2132875086t": ActionCode(
        0, "1040876951t", [], [], "AutoSheets Delete Rows/Columns", [], []
    ),
    "214t": ActionCode(0, "", [], [], "Wireless Settings", [], []),
    "2142731215t": ActionCode(
        0, "1040876951t", [], [], "AutoSheets Duplicate Sheet", [], []
    ),
    "215e": ActionCode(0, "", [], [], "Button: Camera", [], []),
    "216e": ActionCode(0, "", [], [], "Button: Long Search", [], []),
    "216t": ActionCode(
        2, "", ["0", "1"], ["Str", "ConditionList"], "App Settings", ["0"], ["App"]
    ),
    "218t": ActionCode(0, "", [], [], "Bluetooth Settings", [], []),
    "219t": ActionCode(0, "", [], [], "Quick Settings", [], []),
    "220e": ActionCode(0, "", [], [], "File Moved", [], []),
    "220t": ActionCode(0, "", [], [], "Mobile Data Settings", [], []),
    "222e": ActionCode(
        0, "", 0, [], "File Modified", ["0", "1"], ["File:", ", Event:"]
    ),
    "222t": ActionCode(0, "", [], [], "Display Settings", [], []),
    "224e": ActionCode(0, "", [], [], "File Closed", [], []),
    "224t": ActionCode(0, "", [], [], "Locale Settings", [], []),
    "226e": ActionCode(0, "", [], [], "File Opened", [], []),
    "226t": ActionCode(0, "", [], [], "App Manager Settings", [], []),
    "227t": ActionCode(0, "", [], [], "Memory Card Settings", [], []),
    "228e": ActionCode(0, "", [], [], "File Deleted", [], []),
    "228t": ActionCode(0, "", [], [], "Network Operator Settings", [], []),
    "229t": ActionCode(0, "", [], [], "Quick Launch Settings", [], []),
    "22t": ActionCode(0, "", [], [], "Load Last App", [], []),
    "230e": ActionCode(0, "", [], [], "File Attribute Change", [], []),
    "230t": ActionCode(0, "", [], [], "Security Settings", [], []),
    "231t": ActionCode(0, "", [], [], "Search Settings", [], []),
    "232t": ActionCode(0, "", [], [], "Sound Settings", [], []),
    "234244923t": ActionCode(
        0, "1040876951t", [], [], "AutoInput Unlock Screen", [], []
    ),
    "234t": ActionCode(0, "", [], [], "Dictionary Settings", [], []),
    "235t": ActionCode(
        6,
        "",
        ["0", "1", "2", "3", "4", "5"],
        ["Int", "Str", "Str", "Int", "Str", "ConditionList"],
        "Custom Settings",
        ["0", "1", "2", "3", "4"],
        [
            ["Test:", "l", "235"],
            ", Name:",
            ", Value:",
            ["", "e", "Use Root"],
            ", Read Setting To:",
        ],
    ),
    "236t": ActionCode(0, "", [], [], "Accessibility Settings", [], []),
    "237t": ActionCode(0, "", [], [], "Notification Listener Settings", [], []),
    "238t": ActionCode(0, "", [], [], "Privacy Settings", [], []),
    "239t": ActionCode(0, "", [], [], "Print Settings", [], []),
    "24081025t": ActionCode(
        0, "1040876951t", [], [], "AutoNotification Snooze", [], []
    ),
    "244t": ActionCode(0, "", [], [], "Toggle Split Screen", [], []),
    "245t": ActionCode(0, "", [], [], "Back Button", [], []),
    "246t": ActionCode(0, "", [], [], "Long Power Button", [], []),
    "247t": ActionCode(0, "", [], [], "Show Recents", [], []),
    "248t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Int", "Int"],
        "Turn Off",
        ["0", "1"],
        ["File:", ["", "e", "Dim"], ["", "e", ", Lock"]],
    ),
    "249t": ActionCode(0, "", [], [], "System Screenshot", [], []),
    "250t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Str", "Str"],
        "Compose SMS",
        ["0", "1"],
        ["Recipient(s):", "Message:"],
    ),
    "251t": ActionCode(0, "", [], [], "Battery Settings", [], []),
    "252t": ActionCode(1, "", ["0"], ["App"], "Set SMS App", ["0"], ["App:"]),
    "254t": ActionCode(
        1, "", ["0"], ["Int"], "Speakerphone", ["0"], [["Set:", "l", "switch_set"]]
    ),
    "256t": ActionCode(
        1, "", ["0"], ["Int"], "Vibrate On Ringer", ["0"], [["Set:", "l", "switch_set"]]
    ),
    "257t": ActionCode(0, "", [], [], "Power Usage Settings", [], []),
    "258t": ActionCode(0, "", [], [], "Vibrate On Notify", [], []),
    "259t": ActionCode(
        1,
        "",
        ["0"],
        ["Int"],
        "Notification Pulse",
        ["0"],
        [["Set:", "l", "switch_set"]],
    ),
    "25t": ActionCode(0, "", [], [], "Go Home", [], []),
    "260559060t": ActionCode(
        0, "1040876951t", [], [], "AutoNotification Block", [], []
    ),
    "263029931t": ActionCode(
        0, "1040876951t", [], [], "AutoInput Unlock Screen", [], []
    ),
    "268157305t": ActionCode(
        0, "1040876951t", [], [], "AutoNotification Tiles", [], []
    ),
    "294t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Int", "ConditionList"],
        "Bluetooth",
        ["0"],
        [["Set:", "l", "switch_set"]],
    ),
    "295t": ActionCode(1, "", ["0"], ["Str"], "Bluetooth ID", ["0"], ["Name:"]),
    "296t": ActionCode(
        1, "", ["0"], ["Int"], "Bluetooth Voice", ["0"], [["Set:", "l", "switch_set"]]
    ),
    "2e": ActionCode(0, "", [], [], "Phone Offhook", [], []),
    "2s": ActionCode(
        1,
        "",
        ["0"],
        ["Int"],
        "Mobile Data Settings",
        ["0"],
        [["Set:", "l", "switch_set"]],
    ),
    "3000e": ActionCode(0, "", [], [], "Gesture", [], []),
    "3001e": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Int", "Int", "Int"],
        "Shake",
        ["0", "1", "2"],
        [
            ["Axis:", "l", "3001e"],
            ["Sensitivity:", "l", "3001ea"],
            ["Duration:", "l", "3001eb"],
        ],
    ),
    "300e": ActionCode(0, "", [], [], "Date Set", [], []),
    "300t": ActionCode(1, "", ["0"], ["Int"], "Anchor", ["0"], ["Label"]),
    "301t": ActionCode(0, "", [], [], "Mic Mute", [], []),
    "302e": ActionCode(0, "", [], [], "Time/Date Set", [], []),
    "303e": ActionCode(0, "", [], [], "Timer Change", [], []),
    "303t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Int", "Int", "Int"],
        "Alarm Volume",
        ["0", "1", "2"],
        ["Level:", ["", "e", ", Display"], ["", "e", ", Sound"]],
    ),
    "304e": ActionCode(0, "", [], [], "Timezone Set", [], []),
    "304t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Int", "Int", "Int"],
        "Ringer Volume",
        ["0", "1", "2"],
        ["Level:", ["", "e", ", Display"], ["", "e", ", Sound"]],
    ),
    "3050e": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Str", "Str", "Int"],
        "Variable Set",
        ["0", "1", "2"],
        ["Variable:", ", Value:", ["", "e", ", User Variables Only"]],
    ),
    "305e": ActionCode(0, "", [], [], "Alarm Clock", [], []),
    "305t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Int", "Int", "Int", "ConditionList"],
        "Notification Volume",
        ["0", "1", "2"],
        ["Level:", ["", "e", ", Display"], ["", "e", ", Sound"]],
    ),
    "3060e": ActionCode(0, "", [], [], "Variable Cleared", [], []),
    "306e": ActionCode(0, "", [], [], "Alarm Done", [], []),
    "306t": ActionCode(0, "", [], [], "In-Call Volume", [], []),
    "3071e": ActionCode(0, "", [], [], "Zoom Click", [], []),
    "307e": ActionCode(0, "", [], [], "Monitor Start", [], []),
    "307t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Int", "Int", "Int", "ConditionList"],
        "Media Volume",
        ["0", "1", "2"],
        ["Level:", ["", "e", ", Display"], ["", "e", ", Sound"]],
    ),
    "308t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Int", "Int", "Int"],
        "System Volume",
        ["0", "1", "2"],
        ["Level:", ["", "e", ", Display"], ["", "e", ", Sound"]],
    ),
    "309e": ActionCode(0, "", [], [], "Steps Taken", [], []),
    "309t": ActionCode(0, "", [], [], "DTMF Volume", [], []),
    "30s": ActionCode(
        6,
        "",
        ["0", "1", "2", "3", "4", "5"],
        ["Int", "Int", "Int", "Int", "Int", "ConditionList"],
        "Headset Plugged",
        ["0"],
        [["Type:", "l", "30s"]],
    ),
    "30t": ActionCode(
        6,
        "",
        ["0", "1", "2", "3", "4", "5"],
        ["Int", "Int", "Int", "Int", "Int", "ConditionList"],
        "Wait",
        ["0", "1", "2", "3", "4"],
        ["MS:", ", Seconds:", ", Minutes:", ", Hours:", ", Days:"],
    ),
    "310t": ActionCode(
        1, "", ["0"], ["Int"], "Vibrate Mode", ["0"], [["Mode:", "l", "310"]]
    ),
    "311t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Int", "Int", "Int"],
        "BT Voice Volume",
        ["0", "1", "2"],
        ["Level:", ["", "e", ", Display"], ["", "e", ", Sound"]],
    ),
    "312t": ActionCode(
        8,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7"],
        ["Int", "Int", "Int", "Int", "Str", "Str", "Bundle", "ConditionList"],
        "Do Not Disturb",
        ["0"],
        [["Mode:", "l", "312"]],
    ),
    "313t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Int", "Int", "ConditionList"],
        "Sound Mode",
        ["0", "1"],
        [["Mode:", "l", "313"], ["", "e", ", Ignore DND"]],
    ),
    "314t": ActionCode(
        10,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        ["Int", "Str", "Str", "Str", "Str", "Int", "Str", "Int", "Int", "Int"],
        "Authentication Dialog",
        ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        [
            ["Type:", "l", "314"],
            ", Title:",
            ", Subtitle:",
            ", Description:",
            ", Cancel Button Text:",
            ", Number of Attempts:",
            ", Read Result Into:",
            ", Timeout (Seconds):",
            ["", "e", ", Confirmation Required"],
            ["", "e", ", Device Credentials Allowed"],
        ],
    ),
    "316t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Int", "Str"],
        "Display Size",
        ["0", "1"],
        [["Size:", "l", "316"], ", Manual:"],
    ),
    "317t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Int", "Bundle"],
        "NFC",
        ["0"],
        [["Set:", "l", "switch_set"]],
    ),
    "318t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Int", "Int"],
        "Force Rotation",
        ["0", "1"],
        [["Mode:", "l", "318"], ["", "e", ", Alternative Method (Check Help)"]],
    ),
    "319692633t": ActionCode(
        0, "1040876951t", [], [], "AutoShare Process Text", [], []
    ),
    "319t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Str", "Str"],
        "Ask Permissions",
        ["0", "1"],
        ["Required Permissions:", ", Prompt If Not Granted:"],
    ),
    "320t": ActionCode(
        5,
        "",
        ["0", "1", "2", "3", "4"],
        ["Str", "Int", "Str", "Str", "Str"],
        "Ping",
        ["0", "1", "2", "3", "4"],
        [
            ", Host:",
            ", Number:",
            ", Average Result Variable:",
            ", Min Result Variable:",
            ", Max Result Variable:",
        ],
    ),
    "321t": ActionCode(
        9,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7", "8"],
        ["Bundle", "Str", "Str", "Str", "Str", "Str", "Int", "Int", "Str"],
        "GD Upload",
        ["1", "2", "3", "4", "5", "6", "7", "8"],
        [
            "Google Drive/Account:",
            ", Data/File:",
            ", Remote File Name:",
            ", Remote Folder:",
            ", Content Description:",
            ["", "e", ", Overwrite If Exists"],
            ["", "e", ", Publicly Share File"],
            ", Mime Type:",
        ],
    ),
    "322t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Str", "Str", "Int"],
        "Data Backup",
        ["0", "1", "2"],
        ["Path:", ", Google Drive Account:", ["", "e", ", Include User Vars/Prefs"]],
    ),
    "323t": ActionCode(
        6,
        "",
        ["0", "1", "2", "3", "4", "5"],
        ["Int", "Int", "Int", "Int", "Int", "ConditionList"],
        "Airplane Radios",
        ["0", "1", "2", "3", "4"],
        [
            ["", "e", "Bluetooth"],
            ["", "e", ", Cell"],
            ["", "e", ", NFC"],
            ["", "e", ", Wifi"],
            ["", "e", ", Wimax"],
        ],
    ),
    "324t": ActionCode(
        6,
        "",
        ["0", "1", "2", "3", "4", "5"],
        ["Bundle", "Str", "Int", "Int", "Str", "Str"],
        "GD List",
        ["1", "2", "3", "5"],
        [
            "Google Drive Account:",
            [", Type:", "l", "324"],
            [", Files or Folders:", "l", "324a"],
            ", Query:",
        ],
    ),
    "325t": ActionCode(
        8,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7"],
        ["Bundle", "Str", "Int", "Int", "Str", "Str", "Str", "Str"],
        "GD Trash",
        ["1", "2", "3", "4", "5", "6"],
        [
            "Google Drive Account:",
            [", Trash Value:", "l", "325"],
            [", Type:", "l", "325a"],
            ", File ID:",
            ", Path:",
            ", Remote File Name:",
        ],
    ),
    "326t": ActionCode(
        7,
        "",
        ["0", "1", "2", "3", "4", "5", "6"],
        ["Bundle", "Str", "Int", "Str", "Str", "Str", "Str"],
        "GD Download",
        ["1", "2", "3", "4", "5", "6"],
        [
            "Google Drive Account:",
            [", Type:", "l", "325a"],
            ", File ID:",
            ", Remote Folder:",
            ", Remote File Name:",
            ", Local Path:",
        ],
    ),
    "327t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Bundle", "Str", "Int"],
        "GD Sign In",
        ["1", "2"],
        ["Google Drive Account:", ["", "e", ", Full Access"]],
    ),
    "328t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Bundle", "Str", "Int", "Int"],
        "Keyboard",
        ["1", "2", "3"],
        ["Input", ", Time Between Inputs:", ["", "e", ", Don't Restore Keyboard"]],
    ),
    "329t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Str", "Str", "Str"],
        "Navigation Bar",
        ["0", "1", "2"],
        ["Left:", "Center:", "Right:"],
    ),
    "330t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Bundle", "Str", "Str"],
        "NFC Tag",
        ["1", "2"],
        ["Payload To Write:", ", Payload Type:"],
    ),
    "331t": ActionCode(
        1, "", ["0"], ["Int"], "Auto-Sync", ["0"], [["Set:", "l", "switch_set"]]
    ),
    "332t": ActionCode(0, "", [], [], "GPS", [], []),
    "333t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Int", "Bundle"],
        "Airplane Mode",
        ["0"],
        [["Set:", "l", "switch_set"]],
    ),
    "334t": ActionCode(
        9,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7", "8"],
        ["Str", "Str", "Int", "Int", "Int", "Int", "Str", "Str", "Int"],
        "Say WaveNet",
        ["0", "1", "2", "3", "4", "5", "6", "7"],
        [
            "Test/SSML:",
            ", Voice:",
            [", Type:", "l", "171"],
            ", Pitch:",
            ", Speed:",
            ["", "e", ", Continue Task Immediately"],
            ", File:",
            ", Override API Key:",
            ["", "e", ", Respect Audio Focus"],
        ],
    ),
    "335t": ActionCode(
        5,
        "",
        ["0", "1", "2", "3", "4"],
        ["Bundle", "Str", "Str", "Int", "Int"],
        "App Info",
        ["1", "2", "3", "4"],
        [
            "Package/App Name:",
            ", Ignore Packages:",
            ["", "e", ", Ignore Unlaunchable Apps"],
            ["", "e", ", Get All Details"],
        ],
    ),
    "337t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Str", "Str"],
        "Notification Settings",
        ["0", "1"],
        ["Package:", ", Category:"],
    ),
    "338t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Bundle", "Str"],
        "Notification Category Info",
        ["1"],
        ["Category:"],
    ),
    "339t": ActionCode(
        14,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13"],
        [
            "Bundle",
            "Int",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Int",
            "Int",
            "Int",
            "Int",
            "Int",
            "ConditionList",
        ],
        "HTTP Request",
        ["1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12"],
        [
            ["Method:", "l", "339"],
            ", URL:",
            ", Headers:",
            ", Query Parameters:",
            ", Body:",
            ", File To Send:",
            ", File/Directory To Save With Output:",
            ", Timeout:",
            ["", "e", ", Trust Any Certificate"],
            ["", "e", ", Automatically Follow Redirects"],
            ["", "e", ", Use Cookies"],
            ["", "e", ", Structure Output (JSON, etc)"],
        ],
    ),
    "340t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Bundle", "Int", "Str", "Int"],
        "Bluetooth Connection",
        ["1", "2", "3"],
        [["Action:", "l", "340"], ", Device:", ", Timeout:"],
    ),
    "341t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Int", "Str", "Str"],
        "Test Net",
        ["0", "2"],
        [["Type:", "l", "341"], ", Store Result In:"],
    ),
    "342t": ActionCode(
        6,
        "",
        ["0", "1", "2", "3", "4", "5"],
        ["Int", "Str", "Str", "Int", "Int", "ConditionList"],
        "Test File",
        ["0", "1", "2", "3"],
        [
            ["Type:", "l", "342"],
            ", Data:",
            ", Store Result In:",
            ["", "e", ", Use Root"],
        ],
    ),
    "343t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Int", "Str", "Str"],
        "Test Media",
        ["0", "1", "2"],
        [["Type:", "l", "343"], ", Data:", ", Store Result In:"],
    ),
    "344636446t": ActionCode(
        0, "1040876951t", [], [], "AutoVoice Trigger Alexa Routine", [], []
    ),
    "344t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Int", "Str", "Str"],
        "Test App",
        ["0", "1", "2"],
        [["Type:", "l", "344"], ", Data:", ", Store Result In:"],
    ),
    "345t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Int", "Str", "Str"],
        "Test Variable",
        ["0", "1", "2"],
        [["Type:", "l", "345"], ", Data:", ", Store Results In:"],
    ),
    "346t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Int", "Str", "Str"],
        "Test Phone",
        ["0", "1", "2"],
        [["Type:", "l", "346"], ", Data:", ", Store Result In:"],
    ),
    "347t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Int", "Str", "Str", "ConditionList"],
        "Test Tasker",
        ["0", "1", "2"],
        [["Type:", "l", "347"], ", Data:", ", Store Result In:"],
    ),
    "34829087e": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Bundle", "Str", "Str", "Int"],
        "Tools & AmazFit",
        ["0", "3"],
        ["", ["", "e", ", Structure Output (JSON, etc)"]],
    ),
    "348t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Int", "Str", "Str"],
        "Test Display",
        ["0", "1"],
        [["Type:", "l", "348"], ", Store Result In:"],
    ),
    "349t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Int", "Str", "Str"],
        "Test System",
        ["0", "1"],
        [["Type:", "l", "349"], ", Store Result In:"],
    ),
    "351t": ActionCode(
        11,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10"],
        [
            "Bundle",
            "Int",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Int",
            "Int",
            "Str",
            "Str",
        ],
        "HTTP Auth",
        ["1", "2", "3", "4", "5", "6", "7", "8", "9", "10"],
        [
            ["Method:", "l", "351"],
            ", Client ID:",
            ", Client Secret:",
            ", Endpoint To Get Code:",
            ", Endpoint To Get Refresh Token:",
            ", Scopes:",
            ["", "e", "Force Re-Authentication"],
            ", Timeout:",
            ", Username:",
            ", Password:",
        ],
    ),
    "354t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Str", "Str", "Str", "ConditionList"],
        "Array Set",
        ["0", "1", "2"],
        ["Variable Array:", ", Values:", ", Splitter:"],
    ),
    "355t": ActionCode(
        5,
        "",
        ["0", "1", "2", "3", "4"],
        ["Str", "Int", "Str", "Int", "ConditionList"],
        "Array Push",
        ["0", "1", "2", "3"],
        ["Variable Array:", ", Position:", ", Value:", ["", "e", ", Fill Spaces"]],
    ),
    "356t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Str", "Int", "Str", "ConditionList"],
        "Array Pop",
        ["0", "1", "2"],
        ["Variable Array:", ", Position:", ", To Var:"],
    ),
    "357t": ActionCode(
        1, "", ["0"], ["Str"], "Array Clear", ["0"], ["Variable Array:"]
    ),
    "358t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Bundle", "Int", "Str", "Int"],
        "Bluetooth Info",
        ["1", "2", "3"],
        [["Type:", "l", "358"], ", Device:", ", Timeout:"],
    ),
    "35t": ActionCode(
        6,
        "",
        ["0", "1", "2", "3", "4", "5"],
        ["Int", "Int", "Int", "Int", "Int", "ConditionList"],
        "Wait Until",
        ["0", "1", "2", "3", "4"],
        [["if"], "MS:", ", Seconds:", ", Minutes:", ", Hours:", ", Days:"],
    ),
    "360t": ActionCode(
        8,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7"],
        ["Bundle", "Str", "Str", "Str", "Int", "Str", "Int", "Int"],
        "Input Dialog",
        ["1", "2", "3", "4", "5", "6", "7"],
        [
            "Title:",
            ", Text:",
            ", Default Input:",
            ", Close After (Seconds):",
            ", Input Type:",
            ["", "e", ", Use HTML"],
            ["", "e", ", Pre-Select Input"],
        ],
    ),
    "361t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Int", "Bundle"],
        "Dark Mode",
        ["0"],
        [["Set:", "l", "switch_set"]],
    ),
    "362t": ActionCode(1, "", ["0"], ["Str"], "Set Assistant", ["0"], ["Assistant:"]),
    "363t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Int", "Str"],
        "Mobile Network Type",
        ["0"],
        [["Set:", "l", "switch_set"]],
    ),
    "364t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Bundle", "Int"],
        "Text Next Alarm",
        ["1"],
        ["Minutes Difference:"],
    ),
    "365t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Bundle", "Str", "ConditionList"],
        "Tasker Function",
        ["1"],
        ["Function:"],
    ),
    "366t": ActionCode(
        10,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        ["Bundle", "Int", "Str", "Str", "Str", "Str", "Int", "Int", "Str", "Int"],
        "Get Location V2",
        ["1", "2", "3", "4", "5", "6", "7", "8", "9"],
        [
            "Timeout (Seconds):",
            ", Minimum Accuracy (meters):",
            ", Speed (meters/second):",
            ", Altitude (meters):",
            ", Near Location:",
            ["", "e", ", Enable Location If Needed"],
            ["", "e", ", Last Location If Timeout"],
            ", Min Speed Accuracy (m/s):",
            ["", "e", ", Force High Accuracy"],
        ],
    ),
    "367t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Int", "Bundle"],
        "Camera",
        ["0"],
        [["Set:", "l", "switch_set"]],
    ),
    "368t": ActionCode(
        5,
        "",
        ["0", "1", "2", "3", "4"],
        ["Bundle", "Str", "Int", "Str", "Int"],
        "Pick Location",
        ["1", "2", "3", "4"],
        [
            "Title:",
            ["", "e", ", Select Radius"],
            ", Initial Location:",
            [", Set:", "l", "368"],
        ],
    ),
    "369t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Str", "Int", "ConditionList"],
        "Array Process",
        ["0", "1"],
        ["Variable Array:", [", Type:", "l", "369"]],
    ),
    "370t": ActionCode(
        2, "", ["0", "1"], ["Bundle", "Str"], "Shortcut", ["0"], ["Shortcut:"]
    ),
    "371t": ActionCode(0, "", [], [], "Astrid", [], []),
    "372t": ActionCode(
        2, "", ["0", "1"], ["Bundle", "Str"], "Sensor Info", ["1"], ["Type:"]
    ),
    "373t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Bundle", "Str", "Int", "Int"],
        "Test Sensor",
        ["1", "2", "3"],
        ["Type:", ", Timeout (Seconds):", ["", "e", ", Convert Orientation"]],
    ),
    "374t": ActionCode(
        8,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7"],
        ["Bundle", "Int", "Str", "Int", "Str", "Str", "Str", "Str"],
        "Screen Capture",
        ["1", "2", "3", "4", "5", "6"],
        [
            ["Type:", "l", "374"],
            ", Output File:",
            ["", "e", ", Sound"],
            ", Video Encoder:",
            ", Resolution:",
            ", Video Bitrate:",
        ],
    ),
    "375t": ActionCode(0, "", [], [], "ADB Wifi", [], []),
    "376t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Str", "Str", "Int", "Str"],
        "Share File",
        ["0", "1", "2", "3"],
        [
            "File:",
            ", Mime Type:",
            ["", "e", ", Show Chooser Dialog"],
            ", Chooser Dialog Title:",
        ],
    ),
    "377t": ActionCode(
        11,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10"],
        [
            "Bundle",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Int",
            "Int",
            "Str",
            "Str",
            "ConditionList",
        ],
        "Text/Image Dialog",
        ["1", "2", "3", "4", "5", "6", "7", "8", "9"],
        [
            "Title:",
            ", Text:",
            ", Button 1:",
            ", Button 2:",
            ", Button 3:",
            ", Close After (Seconds):",
            ["", "e", ", Use HTML"],
            ", Image:",
            ", Max Width or Height:",
        ],
    ),
    "378t": ActionCode(
        15,
        "",
        [
            "0",
            "1",
            "2",
            "3",
            "4",
            "5",
            "6",
            "7",
            "8",
            "9",
            "10",
            "11",
            "12",
            "13",
            "14",
        ],
        [
            "Bundle",
            "Int",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Int",
            "Int",
            "Int",
            "Int",
            "Str",
            "ConditionList",
        ],
        "List Dialog",
        ["1", "2", "3", "4", "6", "7", "8", "9", "10", "11", "12", "13"],
        [
            ["Mode:", "l", "378"],
            ", Title:",
            ", Items:",
            ", Long Click Task:",
            ", Button 1:",
            ", Button 2:",
            ", Button 3:",
            ", Close After (Seconds):",
            ["", "e", ", Use HTML"],
            ", First Visible Index:",
            ["", "e", ", Hide Filter"],
            ", Text:",
        ],
    ),
    "37s": ActionCode(1, "", ["0"], ["ConditionList"], "Variable Set", [], []),
    "37t": ActionCode(1, "", ["0"], ["ConditionList"], "If", ["if"], [""]),
    "380t": ActionCode(
        10,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        ["Bundle", "Str", "Str", "Str", "Int", "Str", "Str", "Str", "Int", "Str"],
        "HTTP Response",
        ["1", "2", "3", "4", "5", "6", "7", "8"],
        [
            "Request ID:",
            ", Status Code:",
            ", Headers:",
            ["Type:", "l", "380"],
            "",
            ", File:",
            ", Mime Type:",
            ["", "e", ", File Inline"],
        ],
    ),
    "381t": ActionCode(
        5,
        "",
        ["0", "1", "2", "3", "4"],
        ["Bundle", "Str", "Str", "Str", "Int"],
        "Contact Via App",
        ["0", "1"],
        ["Contact:", ", App:"],
    ),
    "383t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Int", "Int"],
        "Settings Panel",
        ["0"],
        [["Contact:", "l", "383"]],
    ),
    "384t": ActionCode(
        15,
        "",
        [
            "0",
            "1",
            "2",
            "3",
            "4",
            "5",
            "6",
            "7",
            "8",
            "9",
            "10",
            "11",
            "12",
            "13",
            "14",
        ],
        [
            "Bundle",
            "Str",
            "Int",
            "Int",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Int",
        ],
        "Device Control (Power Menu Action)",
        ["1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", "14"],
        [
            "ID:",
            [", Action:", "l", "384"],
            [", Type:", "l", "384a"],
            ", Title:",
            ", Subtitle:",
            ", Icon:",
            ", Command:",
            ", Active:",
            ", Range Min:",
            ", Range Max:",
            ", Range Current:",
            "Range Step:",
            ", Range Format:",
            ["", "e", ", Can Use On Locked Device"],
        ],
    ),
    "385t": ActionCode(1, "", ["0"], ["Str"], "Command", ["0"], ["Command:"]),
    "386t": ActionCode(
        6,
        "",
        ["0", "1", "2", "3", "4", "5"],
        ["Bundle", "Int", "Int", "Int", "Int", "Int"],
        "Call Screening",
        ["0", "1", "2"],
        [
            ["ID:", "l", "386"],
            ["", "e", ", Skip Call Log"],
            ["", "e", ", Skip Notification"],
        ],
    ),
    "387t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Int", "Int", "Int"],
        "Accessibility Volume",
        ["0", "1", "2"],
        ["Level:", ["", "e", ", Display"], ["", "e", ", Sound"]],
    ),
    "388543774t": ActionCode(
        0, "1040876951t", [], [], "AutoSheets Insert Empty Rows/Columns", [], []
    ),
    "389t": ActionCode(
        10,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        [
            "Bundle",
            "Str",
            "Str",
            "Str",
            "Str",
            "Int",
            "Int",
            "Int",
            "Int",
            "ConditionList",
        ],
        "Multiple Variables Set",
        ["1", "2", "3", "4", "5", "6", "7"],
        [
            "Names:",
            ", Variable Name Splitter:",
            ", Values:",
            ", Values Splitter:",
            ["", "e", ", Do Maths"],
            ["", "e", ", Keep Existing"],
            ["", "e", ", Structure Output (JSON, etc)"],
        ],
    ),
    "38t": ActionCode(0, "", [], [], "End If", [], []),
    "390t": ActionCode(
        6,
        "",
        ["0", "1", "2", "3", "4", "5"],
        ["Bundle", "Str", "Str", "Str", "Str", "Int"],
        "Pick Input Dialog",
        ["1", "2", "3", "4", "5"],
        [
            "Type:",
            ", Title:",
            ", Text:",
            ", Default Input:",
            ", Close After (Seconds):",
        ],
    ),
    "391t": ActionCode(
        12,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11"],
        [
            "Bundle",
            "Int",
            "Str",
            "Str",
            "Int",
            "Str",
            "Str",
            "Int",
            "Int",
            "Int",
            "Int",
            "ConditionList",
        ],
        "Progress Dialog",
        ["1", "2", "3", "4", "5", "6", "7", "8", "9"],
        [
            ["Action:", "l", "391"],
            ", Title:",
            ", Text:",
            [", Type:", "l", "391a"],
            ", Animation Images:",
            ", Animation Tint:",
            ", Frame Duration:",
            ", Progress:",
            ", Max:",
        ],
    ),
    "392t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Bundle", "Str", "Str"],
        "Set Variable Structure",
        ["1", "2"],
        ["Name:", ", Structure Type:"],
    ),
    "393t": ActionCode(
        7,
        "",
        ["0", "1", "2", "3", "4", "5", "6"],
        ["Bundle", "Str", "Int", "Str", "Str", "Str", "Str"],
        "Array Merge",
        ["1", "2", "3", "4", "5", "6"],
        [
            "Names:",
            [", Title:", "l", "393"],
            ", Joiner:",
            ", Format:",
            ", Output:",
            ", Join Output:",
        ],
    ),
    "394t": ActionCode(
        13,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12"],
        [
            "Bundle",
            "Int",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Int",
            "Int",
            "Int",
            "Str",
            "ConditionList",
        ],
        "Parse/Format DateTime",
        ["1", "2", "3", "4", "5", "7", "8", "9", "10", "11"],
        [
            ["Input Type:", "l", "394"],
            ", Input:",
            ", Input Format:",
            ", Input Separator:",
            ", Output Format:",
            ", Formatted Value Names:",
            ["", "e", ", Get All Details"],
            ["", "e", ", Do Maths"],
            [", Output Offset Type:", "l", "394a"],
            ", Output Offset:",
        ],
    ),
    "395t": ActionCode(0, "", [], [], "JD Status", [], []),
    "396t": ActionCode(
        5,
        "",
        ["0", "1", "2", "3", "4"],
        ["Bundle", "Int", "Str", "Str", "Str"],
        "Simple Match/Regex",
        ["1", "2", "3"],
        [["Type:", "l", "396"], ", Text:", ", Match Pattern/Regex:"],
    ),
    "397t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Bundle", "Int"],
        "Get Material You Colors",
        ["1"],
        [["", "e", "Output Hashtags"]],
    ),
    "398t": ActionCode(1, "", ["0"], ["Str"], "Connect To WiFi", ["0"], ["SSID:"]),
    "399t": ActionCode(
        10,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        ["Bundle", "Str", "Str", "Str", "Str", "Str", "Int", "Int", "Int", "Str"],
        "Variable Map",
        ["1", "2", "3", "4", "5", "7", "8", "9"],
        [
            "Input:",
            ", Input Minimum:",
            ", Input Maximum:",
            ", Output Minimum:",
            ", Output Maximum:",
            ["", "e", ", Invert"],
            ["", "e", ", Restrict Range"],
            ", Max Rounding Digits:",
            ", Output Variable Name:",
        ],
    ),
    "39t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Str", "Str", "Int", "ConditionList"],
        "For",
        ["0", "1", "2"],
        [
            "Variable:",
            ", Items:",
            ["", "e", ", Structure Output (JSON, etc)"],
            ["if"],
            [""],
        ],
    ),
    "3s": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Str", "Str"],
        "BT Connected",
        ["0", "1"],
        ["Name:", ", Address:"],
    ),
    "400t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Str", "Str", "Int", "Int"],
        "Move",
        ["0", "1", "2"],
        ["From:", ", To:", ["", "e", ", Use Root"]],
    ),
    "402t": ActionCode(0, "", ["0"], ["Bundle"], "Get Clipboard", [], []),
    "404t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Str", "Str", "Int", "Int"],
        "Copy File",
        ["0", "1", "2"],
        ["From:", ", To:", ["", "e", ", Use Root"]],
    ),
    "405t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Str", "Str", "Int", "Int"],
        "Copy Dir",
        ["0", "1", "2"],
        ["From:", ", To:", ["", "e", ", Use Root"]],
    ),
    "406t": ActionCode(
        5,
        "",
        ["0", "1", "2", "3", "4"],
        ["Str", "Int", "Int", "Int", "ConditionList"],
        "Delete File",
        ["0", "1"],
        ["File:", ["", "e", ", Use Root"]],
    ),
    "407t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Bundle", "Str", "Str", "Int"],
        "Pick Photos",
        ["1", "2", "3"],
        [",Max Number:", ", Mime Type:", ["", "e", ", Copy To Cache"]],
    ),
    "40830242s": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Bundle", "Str", "Str", "Int"],
        "AutoNotification Intercept",
        ["0", "3"],
        ["Configuration:", ["", "e", ", Structure Output (JSON (etc)"]],
    ),
    "408t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Str", "Int", "Int", "Int"],
        "Delete Directory",
        ["0", "1", "2"],
        ["Directory:", ["", "e", ", Recurse"], ["", "e", ", Use Root"]],
    ),
    "409t": ActionCode(
        5,
        "",
        ["0", "1", "2", "3", "4"],
        ["Str", "Int", "Int", "Int", "ConditionList"],
        "Create Directory",
        ["0", "1", "2"],
        ["Directory:", ["", "e", ", Create All"], ["", "e", ", Use Root"]],
    ),
    "40s": ActionCode(0, "", 0, [], "Call", ["0", "1"], ["Type:", ", Number:"]),
    "40t": ActionCode(0, "", [], [], "End For", [], []),
    "410t": ActionCode(
        5,
        "",
        ["0", "1", "2", "3", "4"],
        ["Str", "Str", "Int", "Int", "ConditionList"],
        "Write File",
        ["0", "1", "2", "3"],
        ["File:", ", Text:", ["", "e", ", Append"], ["", "e", ", Add New Line"]],
    ),
    "411e": ActionCode(0, "", [], [], "Device Boot", [], []),
    "412t": ActionCode(
        7,
        "",
        ["0", "1", "2", "3", "4", "5", "6"],
        ["Str", "Str", "Int", "Int", "Int", "Str", "Int"],
        "List Files",
        ["0", "1", "2", "3", "4", "5"],
        [
            "Directory:",
            ", Match:",
            ["", "e", ", Include Hidden Files"],
            ["", "e", ", Use Root"],
            [", Sort Selection:", "l", "412"],
            ", Variable Array:",
        ],
    ),
    "413t": ActionCode(
        3,
        "",
        ["1", "2", "3"],
        ["Str", "Str", "Str"],
        "Request Add Tile",
        ["1", "2", "3"],
        ["Tile To Add:", "Title:", "Icon:"],
    ),
    "413e": ActionCode(0, "", [], [], "Device Shutdown", [], []),
    "414549629t": ActionCode(0, "1040876951t", [], [], "AutoSpotify Search", [], []),
    "415t": ActionCode(0, "", [], [], "Read Line", [], []),
    "41628340e": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Bundle", "Str", "Str", "Int"],
        "AutoVoice Intercept",
        ["3"],
        [["", "e", ", Structure Output (JSON, etc)"]],
    ),
    "416t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Str", "Str", "Str"],
        "Read Paragraph",
        ["0", "1", "2"],
        ["File:", ", Para:", ", To Var:"],
    ),
    "417t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Str", "Str", "Int"],
        "Read File",
        ["0", "1", "2"],
        ["File:", ", To Var:", ["", "e", ", Structure Output (JSON, etc)"]],
    ),
    "41t": ActionCode(
        5,
        "",
        ["0", "1", "2", "3", "4"],
        ["Str", "Str", "Int", "Str", "Int"],
        "Send SMS",
        ["0", "1", "3", "4"],
        ["Number:", ", Message:", ", SIM Card:", ["", "e", ", Wait For Result"]],
    ),
    "420t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Str", "Int", "Int", "Str"],
        "Zip",
        ["0", "1", "2", "3"],
        ["File:", ["", "e", ", Delete Dialog"], ", Level:", ", Output File:"],
    ),
    "421t": ActionCode(0, "", ["0"], ["Bundle"], "Get Screen Info", [], []),
    "422e": ActionCode(0, "", [], [], "Device Storage Low", [], []),
    "422t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Str", "Int"],
        "UnZip",
        ["0", "1"],
        ["File:", ["", "e", ", Delete Zip"]],
    ),
    "424e": ActionCode(0, "", [], [], "Screebl / TSC", [], []),
    "424t": ActionCode(0, "", ["0"], ["Bundle"], "Get Battery Info", [], []),
    "424867932t": ActionCode(
        0, "1040876951t", [], [], "AutoBubbles Manage Bubble", [], []
    ),
    "425e": ActionCode(0, "", [], [], "K9 Email Received", [], []),
    "425t": ActionCode(
        1, "", ["0"], ["Int"], "Wifi", ["0"], [["Set:", "l", "switch_set"]]
    ),
    "426e": ActionCode(0, "", [], [], "Widget Locker", [], []),
    "426t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Int", "Int", "Int"],
        "Wifi Net",
        ["0", "1", "2"],
        [["Action:", "l", "426"], ["", "e", ", Force"], ["", "e", ", Report Failure"]],
    ),
    "427e": ActionCode(0, "", [], [], "OpenWatch", [], []),
    "427t": ActionCode(
        1, "", ["0"], ["Int"], "Wifi Sleep", ["0"], [["Policy:", "l", "427"]]
    ),
    "427019141t": ActionCode(
        0, "1040876951t", [], [], "AutoNotification Replace Gmail Notifications", [], []
    ),
    "428e": ActionCode(0, "", [], [], "Kaloer Clock", [], []),
    "42924197t": ActionCode(0, "1040876951t", [], [], "Notification Listener", [], []),
    "429032033t": ActionCode(0, "1040876951t", [], [], "AutoContacts Details", [], []),
    "429e": ActionCode(0, "", [], [], "Locale Changed", [], []),
    "42t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Str", "Int", "Str"],
        "Send Data SMS",
        ["0", "1", "2"],
        ["Number:", ", Port:", ", Data:", ["if", ""]],
    ),
    "430t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Bundle", "Int", "ConditionList"],
        "Restart Tasker",
        ["0"],
        [["", "e", ", Only Monitor"]],
    ),
    "431t": ActionCode(
        5,
        "",
        ["0", "1", "2", "3", "4"],
        ["Bundle", "Int", "Str", "Str", "ConditionList"],
        "Accessibility Services",
        ["1", "2"],
        [["Action:", "l", "431"], ", Services"],
    ),
    "433t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Int", "Bundle"],
        "Mobile Data",
        ["0"],
        [["Set:", "l", "switch_set"]],
    ),
    "438t": ActionCode(
        5,
        "",
        ["0", "1", "2", "3", "4"],
        ["Bundle", "Str", "Str", "Str", "Str"],
        "Matter Light",
        ["1", "2", "3", "4"],
        ["Device IDs/Name:", ", Set:", ", Color:", ", Brightness:"],
    ),
    "439t": ActionCode(0, "", [], [], "WiMax", [], []),
    "43t": ActionCode(1, "", ["0"], ["ConditionList"], "Else/Else If", ["if"], [""]),
    "432t": ActionCode(0, "", [], [], "Get Network Info", [], []),
    "440t": ActionCode(0, "", [], [], "Set Timezone", [], []),
    "441t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Int", "Bundle"],
        "Work Profile",
        ["0"],
        [["Set:", "l", "switch_set"]],
    ),
    "442t": ActionCode(0, "", [], [], "SleepBot", [], []),
    "443t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Int", "Int", "App", "Int"],
        "Media Control",
        ["0", "1", "2", "3"],
        [
            ["Cmd:", "l", "443"],
            ["", "e", ", Simulate Media Button"],
            ", Package/App Name:",
            ["", "e", ", Use Notification If Available"],
        ],
    ),
    "444e": ActionCode(0, "", [], [], "Pomodroido", [], []),
    "444t": ActionCode(0, "", [], [], "TeslaLED", [], []),
    "445e": ActionCode(0, "", [], [], "Radardroid", [], []),
    "445t": ActionCode(
        6,
        "",
        ["0", "1", "2", "3", "4", "5"],
        ["Str", "Int", "Int", "Int", "Int", "ConditionList"],
        "Music Play",
        ["0", "1", "2", "3", "4"],
        [
            "File:",
            ", Start:",
            ["", "e", ", Loop"],
            ["Cmd:", "l", "171"],
            ["", "e", ", Continue Task Immediately"],
        ],
    ),
    "446e": ActionCode(0, "", [], [], "Gentle Alarm", [], []),
    "447e": ActionCode(0, "", [], [], "Reddit Notify", [], []),
    "447t": ActionCode(
        6,
        "",
        ["0", "1", "2", "3", "4", "5"],
        ["Str", "Int", "Int", "Int", "Int", "Int"],
        "Music Play Dir",
        ["0", "1", "2", "3", "4", "5"],
        [
            "Directory:",
            ["", "e", ", Subdirs"],
            ["", "e", ", Audio Only"],
            ["", "e", ", Random"],
            ["", "e", ", Flash"],
            ", Maximum Tracks:",
        ],
    ),
    "448e": ActionCode(0, "", [], [], "Notify My Android", [], []),
    "449t": ActionCode(
        1, "", ["0"], ["Int"], "Music Stop", ["0"], [["", "e", ", Clear Dir"]]
    ),
    "450e": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Str", "Str"],
        "New Package",
        ["0", "1"],
        ["Name:", ", Package:"],
    ),
    "450t": ActionCode(0, "", [], [], "APN Droid", [], []),
    "451e": ActionCode(1, "", ["0"], ["Str"], "Package Removed", ["0"], ["Package:"]),
    "451t": ActionCode(1, "", ["0"], ["Int"], "Music Skip", ["0"], ["Jump:"]),
    "453e": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Str", "Str"],
        "Package Updated",
        ["0", "1"],
        ["Name:", ", Package:"],
    ),
    "453t": ActionCode(1, "", ["0"], ["Int"], "Music Back", ["0"], ["Jump:"]),
    "455t": ActionCode(
        5,
        "",
        ["0", "1", "2", "3", "4"],
        ["Str", "Int", "Int", "Int", "Int"],
        "Record Audio",
        ["0", "1", "2", "3"],
        ["File:", [", Source:", "l", "455"], ", MaxSize:", [", Format:", "l", "455a"]],
    ),
    "456t": ActionCode(0, "", [], [], "JD APN", [], []),
    "457t": ActionCode(0, "", [], [], "Default Ringtone", [], []),
    "458t": ActionCode(0, "", [], [], "WidgetLocker", [], []),
    "459t": ActionCode(1, "", ["0"], ["Str"], "Scan Media", ["0"], ["File:"]),
    "460e": ActionCode(0, "", [], [], "Wallpaper Changed", [], []),
    "461e": ActionCode(
        8,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7"],
        ["App", "Str", "Str", "Str", "Str", "Str", "Str", "Int"],
        "Notification",
        ["0", "1", "2", "3", "4", "5", "6", "7"],
        [
            "Owner Application:",
            ", Title:",
            ", Text:",
            ", Subtext:",
            ", Messages:",
            ", Other Text:",
            ", Cat:",
            ["", "e", ", New Only"],
        ],
    ),
    "461t": ActionCode(
        0,
        "",
        [],
        [],
        "Scan Media",
        ["0", "1", "2", "3", "4", "5", "6", "7"],
        [
            "Owner Application:",
            ", Title:",
            ", Text:",
            ", Subtext:",
            ", Messages:",
            ", Other Text:",
            ", Cat:",
            ["", "e", ", New Only"],
        ],
    ),
    "462e": ActionCode(0, "", [], [], "Button Widget Clicked", [], []),
    "463e": ActionCode(0, "", [], [], "New Window", [], []),
    "464e": ActionCode(
        6,
        "",
        ["0", "1", "2", "3", "4", "5"],
        ["App", "Str", "Str", "Str", "Str", "Str"],
        "Notification Removal",
        ["0", "1", "2", "3", "4", "5"],
        [
            "Owner Application:",
            ", Title:",
            ", Text:",
            ", Subtext:",
            ", Messages:",
            ", Other Text:",
        ],
    ),
    "46t": ActionCode(1, "", ["0"], ["Str"], "Create Scene", ["0"], ["Name:"]),
    "475t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Str", "Int"],
        "GZip",
        ["0", "1"],
        ["File:", ["", "e", ", Delete Orig"]],
    ),
    "476t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Str", "Int"],
        "GUnzip",
        ["0", "1"],
        ["File:", ["", "e", ", Delete Zip"]],
    ),
    "47t": ActionCode(
        12,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11"],
        [
            "Str",
            "Int",
            "Int",
            "Int",
            "Int",
            "Int",
            "Int",
            "Int",
            "Int",
            "Int",
            "Int",
            "ConditionList",
        ],
        "Show Scene",
        ["0", "1", "6", "7", "8", "9", "if"],
        [
            "Name:",
            ["Display As:", "l", "47"],
            ["", "e", "Show Exit Button"],
            ["", "e", "Continue Task Immediately"],
            ["", "e", "Allow Outside Boundaries"],
            ["", "e", "Blocking Overlay +"],
            [""],
        ],
    ),
    "48t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Str", "Int", "ConditionList"],
        "Hide Scene",
        ["0", "1"],
        ["Name:", ["Animation:", "l", "48"]],
    ),
    "490t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Int", "Int"],
        "Media Button Events",
        ["0", "1"],
        [["File:", "l", "490"], ["", "e", ", Use New API"]],
    ),
    "49t": ActionCode(
        2, "", ["0", "1"], ["Str", "ConditionList"], "Destroy Scene", ["0"], ["Name:"]
    ),
    "4e": ActionCode(0, "", [], [], "Phone Idle", [], []),
    "502102143t": ActionCode(
        0, "1040876951t", [], [], "AutoSheets Get Spreadsheet", [], []
    ),
    "4s": ActionCode(0, "", [], [], "Phone Idle", ["0"], [["Priority:", "l", "4s"]]),
    "502807688t": ActionCode(
        0, "1040876951t", [], [], "AutoAppsHub SendCommand", [], []
    ),
    "50s": ActionCode(0, "", [], [], "Keyboard Out", [], []),
    "50t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Str", "Str", "Int", "ConditionList"],
        "Element Value",
        ["0", "1", "2"],
        ["Scene Name:", ", Element:", ", Value:"],
    ),
    "511t": ActionCode(
        1,
        "",
        ["0", "1"],
        ["Int", "Str"],
        "Torch",
        ["0"],
        [["File:", "l", "switch_set"]],
    ),
    "512t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Int", "ConditionList"],
        "Status Bar",
        ["0"],
        [["File:", "l", "512"]],
    ),
    "513t": ActionCode(0, "", [], [], "Close System Dialogs", [], []),
    "51t": ActionCode(
        6,
        "",
        ["0", "1", "2", "3", "4", "5"],
        ["Str", "Str", "Int", "Str", "Str", "ConditionList"],
        "Element Text",
        ["0", "1", "2", "3", "4"],
        [
            "Scene Name:",
            ", Element:",
            [", Position:", "l", "51"],
            ", Text:",
            ", Selection:",
        ],
    ),
    "523t": ActionCode(
        13,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12"],
        [
            "Str",
            "Str",
            "Img",
            "Int",
            "Int",
            "Int",
            "Int",
            "Int",
            "Int",
            "Str",
            "Str",
            "Str",
            "ConditionList",
        ],
        "Notify",
        ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11"],
        [
            "Title:",
            ", Text:",
            ", Icon:",
            "",
            ["", "e", ", Permanent"],
            ", Priority:",
            ["", "e", ", Repeat Alert"],
            [", LED Color:", "l", "523"],
            ", LED Rate:",
            ", Sound File:",
            ", Vibration Pattern:",
            ", Cat:",
            "Actions:",
        ],
    ),
    "525t": ActionCode(
        8,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7"],
        ["Str", "Str", "Img", "Int", "Int", "Int", "Int", "Int"],
        "Notify LED",
        ["0", "1", "2", "3", "4", "5", "6", "7"],
        [
            ":Title:",
            ", Text:",
            ", Icon:",
            "",
            [", LED Color:", "l", "523"],
            ", Rate:",
            ", Priority:",
            ["", "e", ", Repeat Alert"],
        ],
    ),
    "536t": ActionCode(
        7,
        "",
        ["0", "1", "2", "3", "4", "5", "6"],
        ["Str", "Str", "Img", "Int", "Str", "Int", "Int"],
        "Notify Vibrate",
        ["0", "1", "2", "4", "5", "6"],
        [
            "Title:",
            ", Text:",
            ", Icon:",
            ", Pattern:",
            ", Priority:",
            ["", "e", ", Repeat Alert"],
        ],
    ),
    "538t": ActionCode(
        7,
        "",
        ["0", "1", "2", "3", "4", "5", "6"],
        ["Str", "Str", "Img", "Int", "Str", "Int", "Int"],
        "Notification Sound",
        ["0", "1", "2", "4", "5"],
        [
            "Title:",
            ", Text:",
            ", Icon:",
            ", Sound File:",
            ", Priority:",
            ["", "e", ", Repeat Alert"],
        ],
    ),
    "53t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Str", "Str", "Int", "Str"],
        "Element Web Control",
        ["0", "1", "2"],
        ["Scene Name:", ", Element:", [", Mode:", "l", "53"]],
    ),
    "543t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Int", "Str", "Int"],
        "Start System Timer",
        ["0", "1", "2"],
        ["Seconds:", ", Message:", ["", "e", ", Show UI"]],
    ),
    "544t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Str", "Int"],
        "Timer Widget Control",
        ["0", "1"],
        ["Name:", [", Type:", "l", "544"]],
    ),
    "545t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Str", "Int", "Int"],
        "Variable Randomize",
        ["0", "1", "2"],
        ["Name:", ", Min:", ", Max:"],
    ),
    "546t": ActionCode(
        5,
        "",
        ["0", "1", "2", "3", "4"],
        ["Str", "Int", "Int", "Int", "Int"],
        "Timer Widget Set",
        ["0", "1", "2", "3", "4"],
        ["Name:", ", Seconds:", ", Minutes:", ", Hours:", ", Days:"],
    ),
    "547e": ActionCode(
        8,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7"],
        ["Str", "Str", "Int", "Int", "Int", "Int", "Int", "ConditionList"],
        "unmapped",
        [],
        [],
    ),
    "547t": ActionCode(
        8,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7"],
        ["Str", "Str", "Int", "Int", "Int", "Int", "Int", "ConditionList"],
        "Variable Set",
        ["0", "1", "2", "4", "5", "6"],
        [
            "Name:",
            ", To:",
            ["", "e", ", Recursive Variables"],
            ["", "e", ", Do Maths"],
            ["", "e", ", Append"],
            ", Max Rounding Digits:",
            ["", "e", ", Structure Output (JSON, etc)"],
        ],
    ),
    "548t": ActionCode(
        16,
        "",
        [
            "0",
            "1",
            "2",
            "3",
            "4",
            "5",
            "6",
            "7",
            "8",
            "9",
            "10",
            "11",
            "12",
            "13",
            "14",
            "15",
        ],
        [
            "Str",
            "Int",
            "Int",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Int",
            "Str",
            "Int",
            "Int",
            "Str",
            "Int",
            "ConditionList",
        ],
        "Flash",
        [
            "0",
            "1",
            "2",
            "3",
            "4",
            "5",
            "6",
            "7",
            "8",
            "9",
            "10",
            "11",
            "12",
            "13",
            "14",
        ],
        [
            "Text:",
            ["", "e", ", Long"],
            ["", "e", ", Tasker Layout"],
            ", Title:",
            ", Icon:",
            " Icon Size:",
            ", Background Color:",
            ", Task:",
            ", Timeout:",
            ["", "e", ", Continue Task Immediately"],
            ", Text Color:",
            ["", "e", ", Dismiss On Click"],
            ["", "e", ", Show Over Everything"],
            ", Position:",
            ["", "e", ", Use HTML"],
        ],
    ),
    "549t": ActionCode(
        5,
        "",
        ["0", "1", "2", "3", "4"],
        ["Str", "Int", "Int", "Int", "ConditionList"],
        "Variable Clear",
        ["0", "1", "2"],
        ["Name:", ["", "e", ", Pattern Matching"], ["", "e", ", Clear All Variables"]],
    ),
    "54t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Str", "Str", "Str"],
        "Element Text Color",
        ["0", "1", "2"],
        ["Scene Name:", ", Element:", " Colour:"],
    ),
    "550t": ActionCode(
        6,
        "",
        ["0", "1", "2", "3", "4", "5"],
        ["Str", "Str", "Str", "Str", "Int", "Int"],
        "Popup",
        ["0", "1", "2", "4", "5"],
        [
            "Title:",
            ", Text:",
            ", Background Image:",
            ", Layout:",
            ", Timeout (Seconds):",
            ["", "e", ", Show Over Keyguard"],
        ],
    ),
    "551t": ActionCode(0, "", [], [], "Menu", [], []),
    "552t": ActionCode(
        9,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7", "8"],
        ["Str", "Int", "Str", "Str", "Str", "Str", "Str", "Int", "Int"],
        "Popup Task Buttons",
        ["0", "1", "2", "3", "4", "5", "6", "7", "8"],
        [
            "Text:",
            [", Mode:", "l", "552"],
            ", Task:",
            ", Task:",
            ", Task:",
            ", Background Image:",
            ", Layout:",
            ", Timeout (Seconds):",
            ["", "e", ", Show Over Keyguard"],
        ],
    ),
    "553t": ActionCode(0, "", [], [], "SMS Backup+", [], []),
    "555t": ActionCode(0, "", [], [], "BeyondPod", [], []),
    "556t": ActionCode(0, "", [], [], "GrazeRSS", [], []),
    "557649458t": ActionCode(0, "1040876951t", [], [], "AutoWear Time", [], []),
    "558t": ActionCode(0, "", [], [], "Android Notifier", [], []),
    "559t": ActionCode(
        9,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7", "8"],
        ["Str", "Str", "Int", "Int", "Int", "Int", "Int", "Int", "ConditionList"],
        "Say",
        ["0", "1", "2", "3", "4", "5", "6", "7"],
        [
            "Text:",
            ", Engine Voice:",
            [", Stream:", "l", "171"],
            ", Pitch:",
            ", Speed:",
            ["", "e", ", Respect Audio Focus"],
            ["", "e", ", Network"],
            ["", "e", ", Continue Task Immediately"],
        ],
    ),
    "55t": ActionCode(
        5,
        "",
        ["0", "1", "2", "3", "4"],
        ["Str", "Str", "Str", "Str", "ConditionList"],
        "Element Back Color",
        ["0", "1", "2", "3"],
        ["Scene Name:", ", Element:", " Colour:", " End Colour:"],
    ),
    "563213414t": ActionCode(
        0, "1040876951t", [], [], "AutoNotification Table", [], []
    ),
    "565385068t": ActionCode(
        0, "1040876951t", [], [], "AutoNotification Query", [], []
    ),
    "566t": ActionCode(
        7,
        "",
        ["0", "1", "2", "3", "4", "5", "6"],
        ["Int", "Int", "Str", "Str", "Int", "Int", "ConditionList"],
        "Set Alarm",
        ["0", "1", "2", "3", "4", "5"],
        [
            "Hours:",
            ", Minutes:",
            ", Label:",
            ", Sound:",
            [", Vibrate:", "l", "566"],
            ["", "e", ", Confirm"],
        ],
    ),
    "567t": ActionCode(
        8,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7"],
        ["Str", "Str", "Str", "Str", "Str", "Int", "Int", "ConditionList"],
        "Calendar Insert",
        ["0", "1", "2", "3", "4", "5", "6"],
        [
            "In/For Minutes:",
            ", Calendar:",
            ", Title:",
            ", Description:",
            ", Location:",
            ["", "e", ", Available"],
            ["", "e", ", All Day"],
        ],
    ),
    "568t": ActionCode(0, "", [], [], "DailyRoads Voyager", [], []),
    "5683503e": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Bundle", "Str", "Str", "Int"],
        "AutoInput UI Action",
        ["0", "3"],
        ["", ["", "e", ", Structure Output (JSON, etc)"]],
    ),
    "56t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Str", "Str", "Int", "Str"],
        "Element Border",
        ["0", "1", "2", "3"],
        ["Scene Name:", ", Element:", ", Width:", ", Colour:"],
    ),
    "57t": ActionCode(
        6,
        "",
        ["0", "1", "2", "3", "4", "5"],
        ["Str", "Str", "Int", "Int", "Int", "Int"],
        "Element Size",
        ["0", "1", "2", "3", "4", "5"],
        [
            "Scene Name:",
            ", Element:",
            [", Orientation:", "l", "57"],
            ", X:",
            ", Y:",
            ", Animation Time (MS):",
        ],
    ),
    "570237327t": ActionCode(
        0, "1040876951t", [], [], "AutoSheets Format Cells", [], []
    ),
    "580953799e": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Bundle", "Str", "Str", "Int"],
        "AutoShare",
        ["3"],
        [["", "e", ", Structure Output (JSON, etc)"]],
    ),
    "58t": ActionCode(
        6,
        "",
        ["0", "1", "2", "3", "4", "5"],
        ["Str", "Str", "Int", "Int", "Int", "Int"],
        "Element Size",
        ["0", "1", "2", "3", "4", "5"],
        [
            "Scene Name:",
            ", Element:",
            [", Orientation:", "l", "57"],
            ", Width:",
            ", Height:",
            ", Animation Time (MS):",
        ],
    ),
    "590t": ActionCode(
        5,
        "",
        ["0", "1", "2", "3", "4"],
        ["Str", "Str", "Int", "Int", "ConditionList"],
        "Variable Split",
        ["0", "1", "2", "3"],
        ["Name:", ", Splitter:", ["", "e", ", Delete Base"], ["", "e", ", Regex"]],
    ),
    "592t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Str", "Str", "Int"],
        "Variable Join",
        ["0", "1", "2"],
        ["Name:", ", Joiner:", ["", "e", ", Delete Parts"]],
    ),
    "595t": ActionCode(
        8,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7"],
        ["Str", "Str", "Int", "Str", "Str", "Str", "Int", "Int"],
        "Variable Query",
        ["0", "1", "2", "3", "4", "5", "6", "7"],
        [
            "Title:",
            ", Variable:",
            [", Input Type:", "l", "595"],
            ", Default:",
            ", Background Image:",
            ", Layout:",
            ", Timeout (Seconds):",
            ["", "e", ", Show Over Keyguard"],
        ],
    ),
    "596t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Str", "Int", "Str", "Int"],
        "Variable Convert",
        ["0", "1", "2"],
        ["Name:", [", Function:", "l", "596"], ", Store Result In:"],
    ),
    "597t": ActionCode(
        5,
        "",
        ["0", "1", "2", "3", "4"],
        ["Str", "Int", "Int", "Int", "Str"],
        "Variable Section",
        ["0", "1", "2", "3", "4"],
        [
            "Name:",
            ", From:",
            ", Length:",
            ["", "e", ", Adopt To Fit"],
            ", Store Result In:",
        ],
    ),
    "598t": ActionCode(
        9,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7", "8"],
        ["Str", "Str", "Int", "Int", "Int", "Str", "Int", "Str", "ConditionList"],
        "Variable Search Replace",
        ["0", "1", "2", "3", "4", "5", "6"],
        [
            "Variable:",
            ", Search:",
            ["", "e", ", Ignore Case"],
            ["", "e", ", Multi-Line"],
            ["", "e", ", One Match Only"],
            ", Show Matches In Array:",
            ["", "e", ", Replace Matches"],
        ],
    ),
    "599e": ActionCode(
        5,
        "",
        ["0", "1", "2", "3", "4"],
        ["Str", "Int", "Int", "Str", "Str"],
        "Intent Received",
        ["1", "2", "3", "4"],
        [
            "Action:",
            [", Cat:", "l", "877"],
            [", Cat:", "l", "877"],
            ", Schema:",
            ", Mime Type:",
            ", Priority:",
            ["", "e", ", Stop Event"],
        ],
    ),
    "599t": ActionCode(0, "", [], [], "Due Today", [], []),
    "59t": ActionCode(0, "", [], [], "Reboot", [], []),
    "5s": ActionCode(0, "", [], [], "Calendar Entry", [], []),
    "60t": ActionCode(
        9,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7", "8"],
        ["Str", "Str", "Str", "Str", "Str", "Int", "Int", "Str", "Img"],
        "Element Add GeoMarker",
        ["0", "1", "2", "3", "4", "5"],
        [
            "Scene Name:",
            ", Element:",
            ", Lat,Long:",
            ", Label:",
            ", Spot Radius (Meters):",
            ", Spot Color:",
        ],
    ),
    "612t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Str", "Str", "Int", "Str"],
        "Element Video Control",
        ["0", "1", "2", "3"],
        ["Scene Name:", ", Element:", [", Mode:", "l", "612"], ", MilliSeconds:"],
    ),
    "61t": ActionCode(
        2, "", ["0", "1"], ["Int", "ConditionList"], "Vibrate", ["0"], ["Time:"]
    ),
    "62t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Str", "ConditionList"],
        "Vibrate Pattern",
        ["0"],
        ["Pattern:"],
    ),
    "63t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Str", "Str", "Str", "Str"],
        "Element Delete GeoMarker",
        ["0", "1", "2", "3"],
        ["Scene Name:", ", Element:", " Lat,Long:", " Label:"],
    ),
    "643t": ActionCode(0, "", [], [], "OfficeTalk", [], []),
    "64t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Str", "Str", "Int", "Str"],
        "Element Map Control",
        ["0", "1", "2"],
        ["Scene Name:", ", Element:", [", Mode:", "l", "64"]],
    ),
    "657t": ActionCode(0, "", [], [], "Record Audio Stop", [], []),
    "65t": ActionCode(
        6,
        "",
        ["0", "1", "2", "3", "4", "5"],
        ["Str", "Str", "Int", "Int", "Int", "ConditionList"],
        "Element Visibility",
        ["0", "1", "2", "3", "4"],
        [
            "Scene Name:",
            ", Element Match:",
            [", Set:", "l", "65"],
            "Animation Time (MS):",
            ["", "e", ", Continue Task Immediately"],
        ],
    ),
    "658527372t": ActionCode(0, "1040876951t", [], [], "AutoTools HTML Read", [], []),
    "664t": ActionCode(
        10,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        ["Str", "Str", "Str", "Str", "Str", "Str", "Str", "Str", "Str", "Str"],
        "Java Function",
        ["0", "1"],
        ["Class or Object:", ", Function:"],
    ),
    "665t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Int", "Str"],
        "Java Object",
        ["0", "1"],
        [["Mode:", "l", "665"], ", Name:"],
    ),
    "667t": ActionCode(0, "", [], [], "SQL Query", [], []),
    "66t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Str", "Str", "Img", "ConditionList"],
        "Element Image",
        ["0", "1", "2"],
        ["Scene Name:", ", Element:", ", Image:"],
    ),
    "67t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Str", "Str", "Int"],
        "Element Depth",
        ["0", "1", "2"],
        ["Scene Name:", ", Element:", ", Set Depth:"],
    ),
    "68t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Str", "Str", "Int"],
        "Element Focus",
        ["0", "1", "2"],
        ["Scene Name:", ", Element:", ["", "e", ", Set"]],
    ),
    "697t": ActionCode(0, "", [], [], "Shut Up", [], []),
    "699t": ActionCode(
        7,
        "",
        ["0", "1", "2", "3", "4", "5", "6"],
        ["Str", "Str", "Str", "Int", "Int", "Int", "Int"],
        "Say To File",
        ["0", "1", "2", "3", "4", "5", "6"],
        [
            "Text:",
            ", Engine/Voice:",
            ", File:",
            ", Pitch:",
            ", Speed:",
            ["", "e", ", Network"],
            ["", "e", ", Continue Task Immediately"],
        ],
    ),
    "69t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Str", "Int", "Int", "Str"],
        "Element Create",
        ["0", "1", "2", "3"],
        ["Scene Name:", [", Set:", "l", "69"], ["", "e", ", Visible"], ", Content:"],
    ),
    "6e": ActionCode(0, "", [], [], "Phone Ringing", [], []),
    "6s": ActionCode(1, "", ["0"], ["Str"], "Phone Ringing", ["0"], ["Contact:"]),
    "701t": ActionCode(0, "", [], [], "Dpad", [], []),
    "702t": ActionCode(0, "", [], [], "Type", [], []),
    "703953103t": ActionCode(0, "1040876951t", [], [], "KLWP Live Wallpaper", [], []),
    "703t": ActionCode(0, "", [], [], "Button", [], []),
    "71t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Str", "Str", "Int"],
        "Element Text Size",
        ["0", "1", "2"],
        ["Scene Name:", ", Element:", ", Text Size:"],
    ),
    "721t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Str", "Int"],
        "Zoom Visibility",
        ["0", "1"],
        ["Element:", ["", "e", ", Set"]],
    ),
    "731t": ActionCode(0, "", [], [], "Take Call", [], []),
    "732t": ActionCode(0, "", [], [], "Radio", [], []),
    "733t": ActionCode(0, "", ["0"], ["Bundle"], "End Call", [], []),
    "734t": ActionCode(0, "", [], [], "Silence Ringer", [], []),
    "735t": ActionCode(0, "", [], [], "Mobile Data 2G/3G", [], []),
    "73t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Str", "Str"],
        "Element Destroy",
        ["0", "1"],
        ["Scene Name:", ", Element:"],
    ),
    "740t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Str", "Str"],
        "Zoom Text",
        ["0", "1"],
        ["Element:", ", Text:"],
    ),
    "741t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Str", "Int"],
        "Zoom Text Size",
        ["0", "1"],
        ["Element:", ", Text Size:"],
    ),
    "742t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Str", "Str"],
        "Zoom Text Color",
        ["0", "1"],
        ["Element:", ", Text Color:"],
    ),
    "760t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Str", "Int"],
        "Zoom Alpha",
        ["0", "1"],
        ["Element:", ", Set:"],
    ),
    "761t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Str", "Str"],
        "Zoom Image",
        ["0", "1"],
        ["Element:", ", URL:"],
    ),
    "762t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Str", "Str", "Str"],
        "Zoom Color",
        ["0", "1", "2"],
        ["Element:", ", Color:", ", End Color:"],
    ),
    "774351906t": ActionCode(0, "1040876951t", [], [], "Join Action", [], []),
    "775t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Str", "Str"],
        "Write Binary",
        ["0", "1"],
        ["Variable:", ", File:"],
    ),
    "776t": ActionCode(0, "", [], [], "Read Binary", [], []),
    "778682267t": ActionCode(0, "1040876951t", [], [], "AutoInput Gestures", [], []),
    "779t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Str", "Int", "ConditionList"],
        "Notify Cancel",
        ["0"],
        ["Title:"],
    ),
    "794294329t": ActionCode(0, "1040876951t", [], [], "AutoSheets Add Sheet", [], []),
    "793t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Str", "Int"],
        "Zoom State",
        ["0", "1"],
        ["Element:", ", State:"],
    ),
    "794t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Str", "Int", "Int", "Int"],
        "Zoom Position",
        ["0", "1", "2", "3"],
        ["Element:", [", Orientation:", "l", "57"], ", X:", ", Y:"],
    ),
    "795t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Str", "Int", "Int", "Int"],
        "Zoom Size",
        ["0", "1", "2", "3"],
        ["Element:", [", Orientation:", "l", "57"], ", Width:", ", Height:"],
    ),
    "7e": ActionCode(
        5,
        "",
        ["0", "1", "2", "3", "4"],
        ["Int", "Str", "Str", "Str", "Str"],
        "Received Text",
        ["0", "1", "2", "3", "4"],
        [["Type:", "l", "7e"], ", Sender:", ", Content:", ", SIM Card:", ", MMS Body:"],
    ),
    "7s": ActionCode(0, "", [], [], "Cell Near", [], []),
    "801498676t": ActionCode(0, "1040876951t", [], [], "AutoSpotify Albums", [], []),
    "804t": ActionCode(0, "", [], [], "Input Method Select", [], []),
    "806t": ActionCode(1, "", ["0"], ["Int"], "Turn On", ["0"], ["Block Time:"]),
    "808t": ActionCode(
        1, "", ["0"], ["Int"], "Auto Brightness", ["0"], [["Set:", "l", "switch_set"]]
    ),
    "80s": ActionCode(0, "", [], [], "Docked", [], []),
    "810t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Int", "Int", "Int", "Int"],
        "Display Brightness",
        ["0", "1", "2"],
        [
            "Level:",
            ["", "e", ", Disable Safeguard"],
            ["", "e", ", Ignore Current Level"],
        ],
    ),
    "811079103t": ActionCode(
        0, "1040876951t", [], [], "AutoInput Global Action", [], []
    ),
    "812t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Int", "Int", "Int"],
        "Display Timeout",
        ["0", "1", "2"],
        ["Secs:", ", Mins:", ", Hours:"],
    ),
    "815t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Int", "Str", "Str"],
        "List Apps",
        ["0", "1", "2"],
        [["Type:", "l", "815"], ", Match:", ", Store Result In:"],
    ),
    "819222800t": ActionCode(0, "1040876951t", [], [], "AutoSpotify Tracks", [], []),
    "820t": ActionCode(
        1, "", ["0"], ["Int"], "Stay On", ["0"], [["Mode:", "l", "820"]]
    ),
    "822t": ActionCode(
        1,
        "",
        ["0"],
        ["Int"],
        "Display Autorotate",
        ["0"],
        [["Set:", "l", "switch_set"]],
    ),
    "864692752t": ActionCode(0, "1040876951t", [], [], "Join", [], []),
    "8618362t": ActionCode(
        0, "1040876951t", [], [], "AutoSpotify Notification", [], []
    ),
    "877t": ActionCode(
        11,
        "",
        ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10"],
        [
            "Str",
            "Int",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Int",
            "ConditionList",
        ],
        "Send Intent",
        ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        [
            "Action:",
            [", Mode:", "l", "877"],
            ", Mime Type:",
            ", Data:",
            ", Extra:",
            ", Extra:",
            ", Extra:",
            ", Package:",
            ", Class:",
            [", Target:", "l", "877a"],
        ],
    ),
    "888t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Str", "Int", "Int"],
        "Variable Add",
        ["0", "1", "2"],
        ["Name:", ", Value:", ", Wrap Around:"],
    ),
    "890t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Str", "Int", "Int"],
        "Variable Subtract",
        ["0", "1", "2"],
        ["Name:", ", Value:", ", Wrap Around:"],
    ),
    "8e": ActionCode(0, "", [], [], "Received Data SMS", [], []),
    "900t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Str", "Str", "Int"],
        "Browse Files",
        ["0", "1", "2"],
        ["Directory:", ", Match:", ["", "e", ", Include Hidden Files"]],
    ),
    "901t": ActionCode(
        1, "", ["0"], ["Int"], "Stop Location", ["0"], [["Set:", "l", "901"]]
    ),
    "902t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Int", "Int", "Int", "Int"],
        "Get Location",
        ["0", "1", "2", "3"],
        [
            ["Set:", "l", "901"],
            ", Timeout (Seconds):",
            ["", "e", ", Continue Task Immediately"],
            ["", "e", ", Keep Tracking"],
        ],
    ),
    "903t": ActionCode(
        7,
        "",
        ["0", "1", "2", "3", "4", "5", "6"],
        ["Str", "Int", "Str", "Int", "Int", "Int", "Bundle"],
        "Get Voice",
        ["0", "1", "2", "3", "4", "5"],
        [
            "Title:",
            [", Mode:", "l", "903"],
            ", Language:",
            ", Maximum Results:",
            ", Timeout:",
            ["", "e", ", Hide Dialog"],
        ],
    ),
    "904t": ActionCode(0, "", [], [], "Voice Command", [], []),
    "905t": ActionCode(
        1, "", ["0"], ["Int"], "Location Mode", ["0"], [["Mode:", "l", "905"]]
    ),
    "906355163t": ActionCode(0, "1040876951t", [], [], "AutoWear Voice Screen", [], []),
    "906t": ActionCode(
        1, "", ["0"], ["Int"], "Immersive Mode", ["0"], [["Mode:", "l", "906"]]
    ),
    "907t": ActionCode(
        1, "", ["0"], ["Str"], "Status Bar Icons", ["0"], ["Icons To Hide:"]
    ),
    "907418897t": ActionCode(
        0, "1040876951t", [], [], "AutoTools Action Report", [], []
    ),
    "909t": ActionCode(
        1, "", ["0"], ["Int"], "Contacts", ["0"], [["Mode:", "l", "909"]]
    ),
    "90t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Str", "Int", "Str"],
        "Call",
        ["0", "1", "2"],
        ["Number:", ["", "e", ", Auto Dial"], ", Sim Card:"],
    ),
    "910t": ActionCode(
        1, "", ["0"], ["Int"], "Call Log", ["0"], [["Mode:", "l", "910"]]
    ),
    "911t": ActionCode(0, "", [], [], "Gentle Alarm", [], []),
    "915t": ActionCode(0, "", [], [], "CPU", [], []),
    "917310686t": ActionCode(0, "1040876951t", [], [], "AutoSpotify Artists", [], []),
    "918403287t": ActionCode(
        0, "1040876951t", [], [], "AutoNotification Categories", [], []
    ),
    "921575593t": ActionCode(0, "1040876951t", [], [], "AutoInput Keyguard", [], []),
    "940160580t": ActionCode(0, "1040876951t", [], [], "AutoShare", [], []),
    "941t": ActionCode(
        4,
        "",
        ["0", "1", "2", "3"],
        ["Str", "Str", "Int", "Int"],
        "HTML Popup",
        ["0", "1", "2", "3"],
        [
            "Code:",
            ", Layout:",
            ", Timeout (Seconds)",
            ["", "e", ", Show Over Keyguard"],
        ],
    ),
    "956t": ActionCode(0, "", [], [], "NFC Settings", [], []),
    "957t": ActionCode(0, "", [], [], "Android Beam Settings", [], []),
    "958t": ActionCode(0, "", [], [], "NFC Payment Settings", [], []),
    "959t": ActionCode(0, "", [], [], "Dream Settings", [], []),
    "95t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Str", "Int"],
        "Call Block",
        ["0", "1"],
        ["Number Match:", ["", "e", "Info"]],
    ),
    "96585332t": ActionCode(0, "1040876951t", [], [], "AutoWear Settings", [], []),
    "97t": ActionCode(
        3,
        "",
        ["0", "1", "2"],
        ["Str", "Str", "Int"],
        "Call Divert",
        ["0", "1", "2"],
        ["From Match:", ", To:", ["", "e", ", Info"]],
    ),
    "985050481t": ActionCode(0, "1040876951t", [], [], "Actions", [], []),
    "987t": ActionCode(0, "", [], [], "Soft Keyboard", [], []),
    "988t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Int", "Int"],
        "Car Mode",
        ["0", "1"],
        [["Set:", "l", "switch_set"], ["", "e", ", Go Home"]],
    ),
    "989t": ActionCode(0, "", [], [], "Night Mode", [], []),
    "999t": ActionCode(0, "", [], [], "Set Light", [], []),
    "99t": ActionCode(
        2,
        "",
        ["0", "1"],
        ["Str", "Int"],
        "Call Revert",
        ["0", "1"],
        ["Number:", ["", "e", "Info"]],
    ),
}
